@@ -17,6 +17,8 @@
 
 package org.apache.flink.cdc.common.event;
 
+import org.apache.flink.cdc.common.annotation.PublicEvolving;
+
 import java.util.Map;
 import java.util.Objects;
 
@@ -24,6 +26,7 @@ import java.util.Objects;
  * A {@link SchemaChangeEvent} that represents an {@code RENAME COLUMN} DDL, which may contain the
  * lenient column type changes.
  */
+@PublicEvolving
 public class RenameColumnEvent implements SchemaChangeEvent {
 
     private static final long serialVersionUID = 1L;
@@ -75,4 +78,9 @@ public class RenameColumnEvent implements SchemaChangeEvent {
     public SchemaChangeEventType getType() {
         return SchemaChangeEventType.RENAME_COLUMN;
     }
+
+    @Override
+    public SchemaChangeEvent copy(TableId newTableId) {
+        return new RenameColumnEvent(newTableId, nameMapping);
+    }
 }
