@@ -24,6 +24,10 @@ public class RouteRule implements Serializable {
 
     private static final long serialVersionUID = 1L;
 
+    public RouteRule(String sourceTable, String sinkTable) {
+        this(sourceTable, sinkTable, null);
+    }
+
     public RouteRule(String sourceTable, String sinkTable, String replaceSymbol) {
         this.sourceTable = sourceTable;
         this.sinkTable = sinkTable;
