@@ -58,6 +58,7 @@ import org.apache.flink.cdc.common.types.VarBinaryType;
 import org.apache.flink.cdc.common.types.VarCharType;
 import org.apache.flink.cdc.common.types.ZonedTimestampType;
 
+import org.apache.flink.shaded.guava31.com.google.common.collect.ArrayListMultimap;
 import org.apache.flink.shaded.guava31.com.google.common.collect.ImmutableList;
 import org.apache.flink.shaded.guava31.com.google.common.collect.Streams;
 import org.apache.flink.shaded.guava31.com.google.common.io.BaseEncoding;
@@ -308,6 +309,139 @@ public class SchemaMergingUtils {
         return coercedRow;
     }
 
+    /**
+     * Try to merge given {@link Schema}s and ensure they're identical. The only difference allowed
+     * is nullability, string and varchar precision, default value, and comments.
+     */
+    public static Schema strictlyMergeSchemas(List<Schema> schemas) {
+        Preconditions.checkArgument(
+                !schemas.isEmpty(), "Trying to merge transformed schemas %s, but got empty list");
+        if (schemas.size() == 1) {
+            return schemas.get(0);
+        }
+
+        List<List<String>> primaryKeys =
+                schemas.stream()
+                        .map(Schema::primaryKeys)
+                        .filter(p -> !p.isEmpty())
+                        .distinct()
+                        .collect(Collectors.toList());
+        List<List<String>> partitionKeys =
+                schemas.stream()
+                        .map(Schema::partitionKeys)
+                        .filter(p -> !p.isEmpty())
+                        .distinct()
+                        .collect(Collectors.toList());
+        List<Map<String, String>> options =
+                schemas.stream()
+                        .map(Schema::options)
+                        .filter(p -> !p.isEmpty())
+                        .distinct()
+                        .collect(Collectors.toList());
+        List<List<String>> columnNames =
+                schemas.stream()
+                        .map(Schema::getColumnNames)
+                        .distinct()
+                        .collect(Collectors.toList());
+
+        Preconditions.checkArgument(
+                primaryKeys.size() <= 1,
+                "Trying to merge transformed schemas %s, but got more than one primary key configurations: %s",
+                schemas,
+                primaryKeys);
+        Preconditions.checkArgument(
+                partitionKeys.size() <= 1,
+                "Trying to merge transformed schemas %s, but got more than one partition key configurations: %s",
+                schemas,
+                partitionKeys);
+        Preconditions.checkArgument(
+                options.size() <= 1,
+                "Trying to merge transformed schemas %s, but got more than one option configurations: %s",
+                schemas,
+                options);
+        Preconditions.checkArgument(
+                columnNames.size() == 1,
+                "Trying to merge transformed schemas %s, but got more than one column name views: %s",
+                schemas,
+                columnNames);
+
+        int arity = columnNames.get(0).size();
+
+        ArrayListMultimap<Integer, DataType> toBeMergedColumnTypes =
+                ArrayListMultimap.create(arity, 1);
+        for (Schema schema : schemas) {
+            List<DataType> columnTypes = schema.getColumnDataTypes();
+            for (int colIndex = 0; colIndex < columnTypes.size(); colIndex++) {
+                toBeMergedColumnTypes.put(colIndex, columnTypes.get(colIndex));
+            }
+        }
+
+        List<String> mergedColumnNames = columnNames.iterator().next();
+        List<DataType> mergedColumnTypes = new ArrayList<>(arity);
+        for (int i = 0; i < arity; i++) {
+            mergedColumnTypes.add(strictlyMergeDataTypes(toBeMergedColumnTypes.get(i)));
+        }
+
+        List<Column> mergedColumns = new ArrayList<>();
+        for (int i = 0; i < mergedColumnNames.size(); i++) {
+            mergedColumns.add(
+                    Column.physicalColumn(mergedColumnNames.get(i), mergedColumnTypes.get(i)));
+        }
+
+        return Schema.newBuilder()
+                .primaryKey(primaryKeys.isEmpty() ? Collections.emptyList() : primaryKeys.get(0))
+                .partitionKey(
+                        partitionKeys.isEmpty() ? Collections.emptyList() : partitionKeys.get(0))
+                .options(options.isEmpty() ? Collections.emptyMap() : options.get(0))
+                .setColumns(mergedColumns)
+                .build();
+    }
+
+    private static DataType strictlyMergeDataTypes(List<DataType> dataTypes) {
+        Preconditions.checkArgument(
+                !dataTypes.isEmpty(),
+                "Trying to merge transformed data types %s, but got empty list");
+
+        List<DataType> simpleMergeTypes =
+                dataTypes.stream().distinct().collect(Collectors.toList());
+        if (simpleMergeTypes.size() == 1) {
+            return simpleMergeTypes.get(0);
+        }
+
+        List<DataTypeRoot> typeRoots =
+                dataTypes.stream()
+                        .map(DataType::getTypeRoot)
+                        .distinct()
+                        .collect(Collectors.toList());
+        Preconditions.checkArgument(
+                typeRoots.size() == 1,
+                "Trying to merge types %s, but got more than one type root: %s",
+                dataTypes,
+                typeRoots);
+
+        // Decay types to the most
+        DataType type = dataTypes.get(0);
+
+        if (type.is(DataTypeRoot.CHAR)) {
+            return DataTypes.CHAR(CharType.MAX_LENGTH);
+        } else if (type.is(DataTypeRoot.VARCHAR)) {
+            return DataTypes.STRING();
+        } else if (type.is(DataTypeRoot.BINARY)) {
+            return DataTypes.BINARY(BinaryType.MAX_LENGTH);
+        } else if (type.is(DataTypeRoot.VARBINARY)) {
+            return DataTypes.VARBINARY(VarBinaryType.MAX_LENGTH);
+        } else if (type.is(DataTypeRoot.TIMESTAMP_WITHOUT_TIME_ZONE)) {
+            return DataTypes.TIMESTAMP(TimestampType.MAX_PRECISION);
+        } else if (type.is(DataTypeRoot.TIMESTAMP_WITH_TIME_ZONE)) {
+            return DataTypes.TIMESTAMP_TZ(ZonedTimestampType.MAX_PRECISION);
+        } else if (type.is(DataTypeRoot.TIMESTAMP_WITH_LOCAL_TIME_ZONE)) {
+            return DataTypes.TIMESTAMP_LTZ(LocalZonedTimestampType.MAX_PRECISION);
+        } else {
+            throw new IllegalArgumentException(
+                    "Unable to merge data types with different precision: " + dataTypes);
+        }
+    }
+
     @VisibleForTesting
     static boolean isDataTypeCompatible(@Nullable DataType currentType, DataType upcomingType) {
         // If two types are identical, they're compatible of course.
