@@ -50,14 +50,12 @@ import org.apache.flink.runtime.client.JobExecutionException;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.jupiter.api.Assertions;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameters;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 
 import java.sql.SQLSyntaxErrorException;
 import java.util.ArrayList;
@@ -73,35 +71,22 @@ import static org.apache.flink.cdc.connectors.doris.sink.DorisDataSinkOptions.PA
 import static org.apache.flink.cdc.connectors.doris.sink.DorisDataSinkOptions.SINK_ENABLE_BATCH_MODE;
 import static org.apache.flink.cdc.connectors.doris.sink.DorisDataSinkOptions.SINK_ENABLE_DELETE;
 import static org.apache.flink.cdc.connectors.doris.sink.DorisDataSinkOptions.USERNAME;
-import static org.junit.Assert.fail;
 
 /** IT tests for {@link DorisMetadataApplier}. */
-@RunWith(Parameterized.class)
-public class DorisMetadataApplierITCase extends DorisSinkTestBase {
+class DorisMetadataApplierITCase extends DorisSinkTestBase {
     private static final StreamExecutionEnvironment env =
             StreamExecutionEnvironment.getExecutionEnvironment();
 
     private static final int DATABASE_OPERATION_TIMEOUT_SECONDS = 5;
 
-    private final boolean batchMode;
-
-    public DorisMetadataApplierITCase(boolean batchMode) {
-        this.batchMode = batchMode;
-    }
-
-    @Parameters(name = "batchMode: {0}")
-    public static Iterable<?> data() {
-        return Arrays.asList(true, false);
-    }
-
-    @BeforeClass
+    @BeforeAll
     public static void before() {
         env.setParallelism(DEFAULT_PARALLELISM);
         env.enableCheckpointing(3000);
         env.setRestartStrategy(RestartStrategies.noRestart());
     }
 
-    @Before
+    @BeforeEach
     public void initializeDatabase() {
         createDatabase(DorisContainer.DORIS_DATABASE_NAME);
 
@@ -114,7 +99,7 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         LOG.info("Database {} created.", DorisContainer.DORIS_DATABASE_NAME);
     }
 
-    @After
+    @AfterEach
     public void destroyDatabase() {
         dropDatabase(DorisContainer.DORIS_DATABASE_NAME);
         // waiting for database to be created
@@ -234,8 +219,9 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                         tableId, Collections.singletonMap("number", DataTypes.FLOAT())));
     }
 
-    @Test
-    public void testDorisDataTypes() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisDataTypes(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
@@ -307,7 +293,8 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                         .primaryKey("id")
                         .build();
 
-        runJobWithEvents(Collections.singletonList(new CreateTableEvent(tableId, schema)));
+        runJobWithEvents(
+                Collections.singletonList(new CreateTableEvent(tableId, schema)), batchMode);
 
         List<String> actual = inspectTableSchema(tableId);
         List<String> expected =
@@ -341,13 +328,14 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test
-    public void testDorisAddColumn() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisAddColumn(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
 
-        runJobWithEvents(generateAddColumnEvents(tableId));
+        runJobWithEvents(generateAddColumnEvents(tableId), batchMode);
 
         List<String> actual = inspectTableSchema(tableId);
 
@@ -363,13 +351,14 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test
-    public void testDorisDropColumn() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisDropColumn(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
 
-        runJobWithEvents(generateDropColumnEvents(tableId));
+        runJobWithEvents(generateDropColumnEvents(tableId), batchMode);
 
         List<String> actual = inspectTableSchema(tableId);
 
@@ -380,13 +369,14 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test
-    public void testDorisRenameColumn() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisRenameColumn(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
 
-        runJobWithEvents(generateRenameColumnEvents(tableId));
+        runJobWithEvents(generateRenameColumnEvents(tableId), batchMode);
 
         List<String> actual = inspectTableSchema(tableId);
 
@@ -399,13 +389,14 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test
-    public void testDorisAlterColumnType() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisAlterColumnType(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
 
-        runJobWithEvents(generateAlterColumnTypeEvents(tableId));
+        runJobWithEvents(generateAlterColumnTypeEvents(tableId), batchMode);
 
         List<String> actual = inspectTableSchema(tableId);
 
@@ -418,13 +409,14 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test
-    public void testDorisAlterColumnTypeWithDefaultValue() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisAlterColumnTypeWithDefaultValue(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
 
-        runJobWithEvents(generateAlterColumnTypeWithDefaultValueEvents(tableId));
+        runJobWithEvents(generateAlterColumnTypeWithDefaultValueEvents(tableId), batchMode);
 
         List<String> actual = inspectTableSchema(tableId);
 
@@ -437,17 +429,25 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test(expected = JobExecutionException.class)
-    public void testDorisNarrowingAlterColumnType() throws Exception {
-        TableId tableId =
-                TableId.tableId(
-                        DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisNarrowingAlterColumnType(boolean batchMode) {
+        Assertions.assertThatThrownBy(
+                        () -> {
+                            TableId tableId =
+                                    TableId.tableId(
+                                            DorisContainer.DORIS_DATABASE_NAME,
+                                            DorisContainer.DORIS_TABLE_NAME);
 
-        runJobWithEvents(generateNarrowingAlterColumnTypeEvents(tableId));
+                            runJobWithEvents(
+                                    generateNarrowingAlterColumnTypeEvents(tableId), batchMode);
+                        })
+                .isExactlyInstanceOf(JobExecutionException.class);
     }
 
-    @Test
-    public void testDorisTruncateTable() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisTruncateTable(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
@@ -465,7 +465,7 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                         new CreateTableEvent(tableId, schema),
                         DataChangeEvent.insertEvent(tableId, generate(schema, 1, 2.3, "Alice")),
                         DataChangeEvent.insertEvent(tableId, generate(schema, 2, 3.4, "Bob")));
-        runJobWithEvents(preparationTestingEvents);
+        runJobWithEvents(preparationTestingEvents, batchMode);
         waitAndVerify(
                 tableId,
                 3,
@@ -478,7 +478,7 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                         new TruncateTableEvent(tableId),
                         DataChangeEvent.insertEvent(tableId, generate(schema, 3, 4.5, "Cecily")),
                         DataChangeEvent.insertEvent(tableId, generate(schema, 4, 5.6, "Derrida")));
-        runJobWithEvents(truncateTestingEvents);
+        runJobWithEvents(truncateTestingEvents, batchMode);
         waitAndVerify(
                 tableId,
                 3,
@@ -486,8 +486,9 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                 DATABASE_OPERATION_TIMEOUT_SECONDS * 1000L);
     }
 
-    @Test
-    public void testDorisDropTable() throws Exception {
+    @ParameterizedTest(name = "batchMode: {0}")
+    @ValueSource(booleans = {true, false})
+    void testDorisDropTable(boolean batchMode) throws Exception {
         TableId tableId =
                 TableId.tableId(
                         DorisContainer.DORIS_DATABASE_NAME, DorisContainer.DORIS_TABLE_NAME);
@@ -505,7 +506,7 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                         new CreateTableEvent(tableId, schema),
                         DataChangeEvent.insertEvent(tableId, generate(schema, 1, 2.3, "Alice")),
                         DataChangeEvent.insertEvent(tableId, generate(schema, 2, 3.4, "Bob")));
-        runJobWithEvents(preparationTestingEvents);
+        runJobWithEvents(preparationTestingEvents, batchMode);
 
         waitAndVerify(
                 tableId,
@@ -514,20 +515,18 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                 DATABASE_OPERATION_TIMEOUT_SECONDS * 1000L);
 
         runJobWithEvents(
-                Arrays.asList(new CreateTableEvent(tableId, schema), new DropTableEvent(tableId)));
+                Arrays.asList(new CreateTableEvent(tableId, schema), new DropTableEvent(tableId)),
+                batchMode);
 
-        SQLSyntaxErrorException thrown =
-                Assertions.assertThrows(
-                        SQLSyntaxErrorException.class, () -> fetchTableContent(tableId, 3));
-        Assertions.assertTrue(
-                thrown.getMessage()
-                        .contains(
-                                String.format(
-                                        "errCode = 2, detailMessage = Unknown table '%s'",
-                                        tableId.getTableName())));
+        Assertions.assertThatThrownBy(() -> fetchTableContent(tableId, 3))
+                .isExactlyInstanceOf(SQLSyntaxErrorException.class)
+                .hasMessageContaining(
+                        String.format(
+                                "errCode = 2, detailMessage = Unknown table '%s'",
+                                tableId.getTableName()));
     }
 
-    private void runJobWithEvents(List<Event> events) throws Exception {
+    private void runJobWithEvents(List<Event> events, boolean batchMode) throws Exception {
         DataStream<Event> stream =
                 env.fromCollection(events, TypeInformation.of(Event.class)).setParallelism(1);
 
@@ -608,6 +607,6 @@ public class DorisMetadataApplierITCase extends DorisSinkTestBase {
                     actual);
             Thread.sleep(1000L);
         }
-        fail(String.format("Failed to verify content of %s.", tableId));
+        Assertions.fail("Failed to verify content of {}.", tableId);
     }
 }
