@@ -59,7 +59,7 @@ import static org.assertj.core.api.Assertions.assertThat;
 
 /** ITCase tests for {@link ElasticsearchDataSink}. */
 @Testcontainers
-public class Elasticsearch6DataSinkITCaseTest {
+class Elasticsearch6DataSinkITCaseTest {
 
     private static final Logger LOG =
             LoggerFactory.getLogger(ElasticsearchDataSinkITCaseTest.class);
@@ -84,7 +84,7 @@ public class Elasticsearch6DataSinkITCaseTest {
     }
 
     @Test
-    public void testElasticsearchSink() throws Exception {
+    void testElasticsearchSink() throws Exception {
         TableId tableId = TableId.tableId("default", "schema", "table");
         List<Event> events = ElasticsearchTestUtils.createTestEvents(tableId);
 
@@ -119,7 +119,7 @@ public class Elasticsearch6DataSinkITCaseTest {
     }
 
     @Test
-    public void testElasticsearchInsertAndDelete() throws Exception {
+    void testElasticsearchInsertAndDelete() throws Exception {
         TableId tableId = TableId.tableId("default", "schema", "table");
         List<Event> events = ElasticsearchTestUtils.createTestEventsWithDelete(tableId);
 
@@ -129,7 +129,7 @@ public class Elasticsearch6DataSinkITCaseTest {
     }
 
     @Test
-    public void testElasticsearchAddColumn() throws Exception {
+    void testElasticsearchAddColumn() throws Exception {
         TableId tableId = TableId.tableId("default", "schema", "table");
         List<Event> events = ElasticsearchTestUtils.createTestEventsWithAddColumn(tableId);
 
@@ -216,8 +216,9 @@ public class Elasticsearch6DataSinkITCaseTest {
         assertThat(((Number) response.getSource().get("id")).intValue()).isEqualTo(expectedId);
         assertThat(((Number) response.getSource().get("number")).doubleValue())
                 .isEqualTo(expectedNumber);
-        assertThat(response.getSource().get("name")).isEqualTo(expectedName);
-        assertThat(response.getSource().get("bool")).isEqualTo(expectedBool);
+        assertThat(response.getSource())
+                .containsEntry("name", expectedName)
+                .containsEntry("bool", expectedBool);
         assertThat(((Number) response.getSource().get("tinyint")).byteValue())
                 .isEqualTo(expectedTinyint);
         assertThat(((Number) response.getSource().get("smallint")).shortValue())
@@ -254,10 +255,11 @@ public class Elasticsearch6DataSinkITCaseTest {
         GetRequest getRequest = new GetRequest(tableId.toString()).id(id);
         GetResponse response = client.get(getRequest, RequestOptions.DEFAULT);
 
-        assertThat(response.getSource()).isNotNull();
-        assertThat(response.getSource().get("id")).isEqualTo(expectedId);
-        assertThat(response.getSource().get("number")).isEqualTo(expectedNumber);
-        assertThat(response.getSource().get("name")).isEqualTo(expectedName);
-        assertThat(response.getSource().get("extra_bool")).isEqualTo(expectedExtraBool);
+        assertThat(response.getSource())
+                .isNotNull()
+                .containsEntry("id", expectedId)
+                .containsEntry("number", expectedNumber)
+                .containsEntry("name", expectedName)
+                .containsEntry("extra_bool", expectedExtraBool);
     }
 }
