@@ -25,7 +25,7 @@ import org.apache.flink.cdc.connectors.mysql.testutils.UniqueDatabase;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.catalog.ObjectPath;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.sql.Connection;
 import java.sql.SQLException;
@@ -37,10 +37,12 @@ import java.util.Map;
 import java.util.stream.Collectors;
 
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.HOSTNAME;
+import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.PARSE_ONLINE_SCHEMA_CHANGES;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.PASSWORD;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.PORT;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.SCAN_BINLOG_NEWLY_ADDED_TABLE_ENABLED;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.SCAN_INCREMENTAL_SNAPSHOT_CHUNK_KEY_COLUMN;
+import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.TABLES;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.TABLES_EXCLUDE;
 import static org.apache.flink.cdc.connectors.mysql.source.MySqlDataSourceOptions.TREAT_TINYINT1_AS_BOOLEAN_ENABLED;
@@ -52,13 +54,13 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Unit tests for {@link MySqlDataSourceFactory}. */
-public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
+class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
 
     private final UniqueDatabase inventoryDatabase =
             new UniqueDatabase(MYSQL_CONTAINER, "inventory", TEST_USER, TEST_PASSWORD);
 
     @Test
-    public void testCreateSource() {
+    void testCreateSource() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
@@ -75,7 +77,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testCreateSourceScanBinlogNewlyAddedTableEnabled() {
+    void testCreateSourceScanBinlogNewlyAddedTableEnabled() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
@@ -95,7 +97,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testNoMatchedTable() {
+    void testNoMatchedTable() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
@@ -113,7 +115,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testExcludeTable() {
+    void testExcludeTable() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
@@ -137,7 +139,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testExcludeAllTable() {
+    void testExcludeAllTable() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
@@ -158,7 +160,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testDatabaseAndTableWithTheSameName() throws SQLException {
+    void testDatabaseAndTableWithTheSameName() throws SQLException {
         inventoryDatabase.createAndInitialize();
         // create a table with the same name of database
         try (Connection connection = inventoryDatabase.getJdbcConnection();
@@ -196,7 +198,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testLackRequireOption() {
+    void testLackRequireOption() {
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
         options.put(PORT.key(), String.valueOf(MYSQL_CONTAINER.getDatabasePort()));
@@ -226,7 +228,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testUnsupportedOption() {
+    void testUnsupportedOption() {
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
         options.put(PORT.key(), String.valueOf(MYSQL_CONTAINER.getDatabasePort()));
@@ -258,18 +260,25 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
 
         // optional option
         options.put(TREAT_TINYINT1_AS_BOOLEAN_ENABLED.key(), "false");
+        options.put(PARSE_ONLINE_SCHEMA_CHANGES.key(), "true");
+        options.put(SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED.key(), "true");
 
         Factory.Context context = new MockContext(Configuration.fromMap(options));
         MySqlDataSourceFactory factory = new MySqlDataSourceFactory();
-        assertThat(factory.optionalOptions().contains(TREAT_TINYINT1_AS_BOOLEAN_ENABLED))
-                .isEqualTo(true);
+        assertThat(factory.optionalOptions())
+                .contains(
+                        TREAT_TINYINT1_AS_BOOLEAN_ENABLED,
+                        PARSE_ONLINE_SCHEMA_CHANGES,
+                        SCAN_BINLOG_NEWLY_ADDED_TABLE_ENABLED);
 
         MySqlDataSource dataSource = (MySqlDataSource) factory.createDataSource(context);
-        assertThat(dataSource.getSourceConfig().isTreatTinyInt1AsBoolean()).isEqualTo(false);
+        assertThat(dataSource.getSourceConfig().isTreatTinyInt1AsBoolean()).isFalse();
+        assertThat(dataSource.getSourceConfig().isParseOnLineSchemaChanges()).isTrue();
+        assertThat(dataSource.getSourceConfig().isAssignUnboundedChunkFirst()).isTrue();
     }
 
     @Test
-    public void testPrefixRequireOption() {
+    void testPrefixRequireOption() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
@@ -288,7 +297,7 @@ public class MySqlDataSourceFactoryTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testAddChunkKeyColumns() {
+    void testAddChunkKeyColumns() {
         inventoryDatabase.createAndInitialize();
         Map<String, String> options = new HashMap<>();
         options.put(HOSTNAME.key(), MYSQL_CONTAINER.getHost());
