@@ -55,10 +55,10 @@ import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
 import org.apache.flink.util.CloseableIterator;
 
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.testcontainers.lifecycle.Startables;
 
 import java.sql.Connection;
@@ -91,7 +91,7 @@ import static org.apache.flink.cdc.connectors.mysql.testutils.MySqSourceTestUtil
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** IT tests for {@link MySqlDataSource}. */
-public class MySqlPipelineITCase extends MySqlSourceTestBase {
+class MySqlPipelineITCase extends MySqlSourceTestBase {
 
     protected static final MySqlContainer MYSQL8_CONTAINER =
             createMySqlContainer(MySqlVersion.V8_0);
@@ -102,21 +102,21 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
     private final StreamExecutionEnvironment env =
             StreamExecutionEnvironment.getExecutionEnvironment();
 
-    @BeforeClass
+    @BeforeAll
     public static void startContainers() {
         LOG.info("Starting containers...");
         Startables.deepStart(Stream.of(MYSQL8_CONTAINER)).join();
         LOG.info("Containers are started.");
     }
 
-    @AfterClass
+    @AfterAll
     public static void stopContainers() {
         LOG.info("Stopping containers...");
         MYSQL8_CONTAINER.stop();
         LOG.info("Containers are stopped.");
     }
 
-    @Before
+    @BeforeEach
     public void before() {
         TestValuesTableFactory.clearAllData();
         env.setParallelism(4);
@@ -125,7 +125,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testInitialStartupMode() throws Exception {
+    void testInitialStartupMode() throws Exception {
         inventoryDatabase.createAndInitialize();
         MySqlSourceConfigFactory configFactory =
                 new MySqlSourceConfigFactory()
@@ -255,6 +255,149 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
                 .isEqualTo(expectedBinlog);
     }
 
+    @Test
+    void testExcludeTables() throws Exception {
+        inventoryDatabase.createAndInitialize();
+        String databaseName = inventoryDatabase.getDatabaseName();
+        MySqlSourceConfigFactory configFactory =
+                new MySqlSourceConfigFactory()
+                        .hostname(MYSQL8_CONTAINER.getHost())
+                        .port(MYSQL8_CONTAINER.getDatabasePort())
+                        .username(TEST_USER)
+                        .password(TEST_PASSWORD)
+                        .databaseList(databaseName)
+                        .tableList(databaseName + ".*")
+                        .excludeTableList(
+                                String.format(
+                                        "%s.customers, %s.orders, %s.multi_max_table",
+                                        databaseName, databaseName, databaseName))
+                        .startupOptions(StartupOptions.initial())
+                        .serverId(getServerId(env.getParallelism()))
+                        .serverTimeZone("UTC")
+                        .includeSchemaChanges(SCHEMA_CHANGE_ENABLED.defaultValue());
+
+        FlinkSourceProvider sourceProvider =
+                (FlinkSourceProvider) new MySqlDataSource(configFactory).getEventSourceProvider();
+        CloseableIterator<Event> events =
+                env.fromSource(
+                                sourceProvider.getSource(),
+                                WatermarkStrategy.noWatermarks(),
+                                MySqlDataSourceFactory.IDENTIFIER,
+                                new EventTypeInfo())
+                        .executeAndCollect();
+        Thread.sleep(10_000);
+
+        TableId tableId = TableId.tableId(databaseName, "products");
+        CreateTableEvent createTableEvent = getProductsCreateTableEvent(tableId);
+
+        // generate snapshot data
+        List<Event> expectedSnapshot = getSnapshotExpected(tableId);
+
+        List<Event> expectedBinlog = new ArrayList<>();
+        try (Connection connection = inventoryDatabase.getJdbcConnection();
+                Statement statement = connection.createStatement()) {
+            expectedBinlog.addAll(executeAlterAndProvideExpected(tableId, statement));
+
+            RowType rowType =
+                    RowType.of(
+                            new DataType[] {
+                                DataTypes.INT().notNull(),
+                                DataTypes.VARCHAR(255).notNull(),
+                                DataTypes.FLOAT(),
+                                DataTypes.VARCHAR(45),
+                                DataTypes.VARCHAR(55)
+                            },
+                            new String[] {"id", "name", "weight", "col1", "col2"});
+            BinaryRecordDataGenerator generator = new BinaryRecordDataGenerator(rowType);
+            // insert more data
+            statement.execute(
+                    String.format(
+                            "INSERT INTO `%s`.`products` VALUES (default,'scooter',5.5,'c-10','c-20');",
+                            databaseName)); // 110
+            expectedBinlog.add(
+                    DataChangeEvent.insertEvent(
+                            tableId,
+                            generator.generate(
+                                    new Object[] {
+                                        110,
+                                        BinaryStringData.fromString("scooter"),
+                                        5.5f,
+                                        BinaryStringData.fromString("c-10"),
+                                        BinaryStringData.fromString("c-20")
+                                    })));
+            statement.execute(
+                    String.format(
+                            "INSERT INTO `%s`.`products` VALUES (default,'football',6.6,'c-11','c-21');",
+                            databaseName)); // 111
+            expectedBinlog.add(
+                    DataChangeEvent.insertEvent(
+                            tableId,
+                            generator.generate(
+                                    new Object[] {
+                                        111,
+                                        BinaryStringData.fromString("football"),
+                                        6.6f,
+                                        BinaryStringData.fromString("c-11"),
+                                        BinaryStringData.fromString("c-21")
+                                    })));
+            statement.execute(
+                    String.format(
+                            "UPDATE `%s`.`products` SET `col1`='c-12', `col2`='c-22' WHERE id=110;",
+                            databaseName));
+            expectedBinlog.add(
+                    DataChangeEvent.updateEvent(
+                            tableId,
+                            generator.generate(
+                                    new Object[] {
+                                        110,
+                                        BinaryStringData.fromString("scooter"),
+                                        5.5f,
+                                        BinaryStringData.fromString("c-10"),
+                                        BinaryStringData.fromString("c-20")
+                                    }),
+                            generator.generate(
+                                    new Object[] {
+                                        110,
+                                        BinaryStringData.fromString("scooter"),
+                                        5.5f,
+                                        BinaryStringData.fromString("c-12"),
+                                        BinaryStringData.fromString("c-22")
+                                    })));
+            statement.execute(
+                    String.format("DELETE FROM `%s`.`products` WHERE `id` = 111;", databaseName));
+            expectedBinlog.add(
+                    DataChangeEvent.deleteEvent(
+                            tableId,
+                            generator.generate(
+                                    new Object[] {
+                                        111,
+                                        BinaryStringData.fromString("football"),
+                                        6.6f,
+                                        BinaryStringData.fromString("c-11"),
+                                        BinaryStringData.fromString("c-21")
+                                    })));
+            // Make some change of excluded tables.
+            statement.execute(
+                    String.format(
+                            "INSERT INTO `%s`.`customers` VALUES(1,\"Anne\",\"Kretchmar\",\"mark@noanswer.org\");",
+                            databaseName));
+            statement.execute(
+                    String.format(
+                            "INSERT INTO `%s`.`customers` VALUES(2,\"Anne\",\"Kretchmar\",\"mark2@noanswer.org\");",
+                            databaseName));
+        }
+        // In this configuration, several subtasks might emit their corresponding CreateTableEvent
+        // to downstream. Since it is not possible to predict how many CreateTableEvents should we
+        // expect, we simply filter them out from expected sets, and assert there's at least one.
+        List<Event> actual =
+                fetchResultsExcept(
+                        events, expectedSnapshot.size() + expectedBinlog.size(), createTableEvent);
+        assertThat(actual.subList(0, expectedSnapshot.size()))
+                .containsExactlyInAnyOrder(expectedSnapshot.toArray(new Event[0]));
+        assertThat(actual.subList(expectedSnapshot.size(), actual.size()))
+                .isEqualTo(expectedBinlog);
+    }
+
     private static <T> List<T> fetchResultsExcept(Iterator<T> iter, int size, T sideEvent) {
         List<T> result = new ArrayList<>(size);
         List<T> sideResults = new ArrayList<>();
@@ -283,7 +426,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testInitialStartupModeWithOpTs() throws Exception {
+    void testInitialStartupModeWithOpTs() throws Exception {
         inventoryDatabase.createAndInitialize();
         Configuration sourceConfiguration = new Configuration();
         sourceConfiguration.set(MySqlDataSourceOptions.HOSTNAME, MYSQL8_CONTAINER.getHost());
@@ -444,7 +587,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
         }
     }
 
-    public void testParseAlterStatement(boolean tinyInt1isBit) throws Exception {
+    private void testParseAlterStatement(boolean tinyInt1isBit) throws Exception {
         env.setParallelism(1);
         inventoryDatabase.createAndInitialize();
 
@@ -596,7 +739,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testSchemaChangeEventstinyInt1isBit() throws Exception {
+    void testSchemaChangeEventstinyInt1isBit() throws Exception {
         testSchemaChangeEvents(true);
     }
 
@@ -634,9 +777,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
                         .executeAndCollect();
         Thread.sleep(5_000);
 
-        List<Event> expected =
-                new ArrayList<>(
-                        getInventoryCreateAllTableEvents(inventoryDatabase.getDatabaseName()));
+        List<Event> expected = new ArrayList<>();
 
         try (Connection connection = inventoryDatabase.getJdbcConnection();
                 Statement statement = connection.createStatement()) {
@@ -645,6 +786,16 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
                     String.format(
                             "ALTER TABLE `%s`.`customers` ADD COLUMN `newcol1` INT NULL;",
                             inventoryDatabase.getDatabaseName()));
+            expected.add(
+                    new CreateTableEvent(
+                            TableId.tableId(inventoryDatabase.getDatabaseName(), "customers"),
+                            Schema.newBuilder()
+                                    .physicalColumn("id", DataTypes.INT().notNull())
+                                    .physicalColumn("first_name", DataTypes.VARCHAR(255).notNull())
+                                    .physicalColumn("last_name", DataTypes.VARCHAR(255).notNull())
+                                    .physicalColumn("email", DataTypes.VARCHAR(255).notNull())
+                                    .primaryKey(Collections.singletonList("id"))
+                                    .build()));
             expected.add(
                     new AddColumnEvent(
                             TableId.tableId(inventoryDatabase.getDatabaseName(), "customers"),
@@ -737,7 +888,17 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
             statement.execute(
                     String.format(
                             "TRUNCATE TABLE `%s`.`orders`;", inventoryDatabase.getDatabaseName()));
-
+            expected.add(
+                    new CreateTableEvent(
+                            TableId.tableId(inventoryDatabase.getDatabaseName(), "orders"),
+                            Schema.newBuilder()
+                                    .physicalColumn("order_number", DataTypes.INT().notNull())
+                                    .physicalColumn("order_date", DataTypes.DATE().notNull())
+                                    .physicalColumn("purchaser", DataTypes.INT().notNull())
+                                    .physicalColumn("quantity", DataTypes.INT().notNull())
+                                    .physicalColumn("product_id", DataTypes.INT().notNull())
+                                    .primaryKey(Collections.singletonList("order_number"))
+                                    .build()));
             expected.add(
                     new TruncateTableEvent(
                             TableId.tableId(inventoryDatabase.getDatabaseName(), "orders")));
@@ -948,7 +1109,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testDanglingDropTableEventInBinlog() throws Exception {
+    void testDanglingDropTableEventInBinlog() throws Exception {
         env.setParallelism(1);
         inventoryDatabase.createAndInitialize();
 
@@ -1005,9 +1166,7 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
                         .executeAndCollect();
         Thread.sleep(5_000);
 
-        List<Event> expectedEvents =
-                new ArrayList<>(
-                        getInventoryCreateAllTableEvents(inventoryDatabase.getDatabaseName()));
+        List<Event> expectedEvents = new ArrayList<>();
 
         expectedEvents.add(
                 new DropTableEvent(
@@ -1192,46 +1351,6 @@ public class MySqlPipelineITCase extends MySqlSourceTestBase {
                         .build());
     }
 
-    private List<CreateTableEvent> getInventoryCreateAllTableEvents(String databaseName) {
-        return Arrays.asList(
-                new CreateTableEvent(
-                        TableId.tableId(databaseName, "products"),
-                        Schema.newBuilder()
-                                .physicalColumn("id", DataTypes.INT().notNull())
-                                .physicalColumn("name", DataTypes.VARCHAR(255).notNull(), "flink")
-                                .physicalColumn("description", DataTypes.VARCHAR(512))
-                                .physicalColumn("weight", DataTypes.FLOAT())
-                                .primaryKey(Collections.singletonList("id"))
-                                .build()),
-                new CreateTableEvent(
-                        TableId.tableId(databaseName, "customers"),
-                        Schema.newBuilder()
-                                .physicalColumn("id", DataTypes.INT().notNull())
-                                .physicalColumn("first_name", DataTypes.VARCHAR(255).notNull())
-                                .physicalColumn("last_name", DataTypes.VARCHAR(255).notNull())
-                                .physicalColumn("email", DataTypes.VARCHAR(255).notNull())
-                                .primaryKey(Collections.singletonList("id"))
-                                .build()),
-                new CreateTableEvent(
-                        TableId.tableId(databaseName, "orders"),
-                        Schema.newBuilder()
-                                .physicalColumn("order_number", DataTypes.INT().notNull())
-                                .physicalColumn("order_date", DataTypes.DATE().notNull())
-                                .physicalColumn("purchaser", DataTypes.INT().notNull())
-                                .physicalColumn("quantity", DataTypes.INT().notNull())
-                                .physicalColumn("product_id", DataTypes.INT().notNull())
-                                .primaryKey(Collections.singletonList("order_number"))
-                                .build()),
-                new CreateTableEvent(
-                        TableId.tableId(databaseName, "multi_max_table"),
-                        Schema.newBuilder()
-                                .physicalColumn("order_id", DataTypes.VARCHAR(128).notNull())
-                                .physicalColumn("index", DataTypes.INT().notNull())
-                                .physicalColumn("desc", DataTypes.VARCHAR(512).notNull())
-                                .primaryKey(Arrays.asList("order_id", "index"))
-                                .build()));
-    }
-
     private List<Event> getSnapshotExpected(TableId tableId) {
         RowType rowType =
                 RowType.of(
