@@ -57,9 +57,9 @@ import io.debezium.connector.mysql.MySqlConnection;
 import io.debezium.jdbc.JdbcConnection;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.testcontainers.shaded.com.google.common.collect.Lists;
 
 import java.nio.file.Files;
@@ -101,14 +101,14 @@ import static org.apache.flink.cdc.connectors.mysql.testutils.MySqSourceTestUtil
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** IT tests to cover various newly added tables during capture process in pipeline mode. */
-public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
+class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
     private final UniqueDatabase customDatabase =
             new UniqueDatabase(MYSQL_CONTAINER, "customer", "mysqluser", "mysqlpw");
 
     private final ScheduledExecutorService mockBinlogExecutor = Executors.newScheduledThreadPool(1);
 
-    @Before
-    public void before() throws SQLException {
+    @BeforeEach
+    void before() throws SQLException {
         TestValuesTableFactory.clearAllData();
         customDatabase.createAndInitialize();
 
@@ -138,8 +138,8 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
         }
     }
 
-    @After
-    public void after() {
+    @AfterEach
+    void after() {
         mockBinlogExecutor.shutdown();
     }
 
@@ -156,7 +156,7 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testScanBinlogNewlyAddedTableEnabled() throws Exception {
+    void testScanBinlogNewlyAddedTableEnabled() throws Exception {
         List<String> tables = Collections.singletonList("address_\\.*");
         Map<String, String> options = new HashMap<>();
         options.put(SCAN_STARTUP_MODE.key(), "timestamp");
@@ -191,13 +191,13 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
                         .filter((event) -> event instanceof CreateTableEvent)
                         .map((event) -> ((SchemaChangeEvent) event).tableId().getTableName())
                         .collect(Collectors.toList());
-        assertThat(tableNames.size()).isEqualTo(2);
+        assertThat(tableNames).hasSize(2);
         assertThat(tableNames.get(0)).isEqualTo("address_beijing");
         assertThat(tableNames.get(1)).isEqualTo("address_shanghai");
     }
 
     @Test
-    public void testScanBinlogNewlyAddedTableEnabledAndExcludeTables() throws Exception {
+    void testScanBinlogNewlyAddedTableEnabledAndExcludeTables() throws Exception {
         List<String> tables = Collections.singletonList("address_\\.*");
         Map<String, String> options = new HashMap<>();
         options.put(TABLES_EXCLUDE.key(), customDatabase.getDatabaseName() + ".address_beijing");
@@ -233,12 +233,12 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
                         .filter((event) -> event instanceof CreateTableEvent)
                         .map((event) -> ((SchemaChangeEvent) event).tableId().getTableName())
                         .collect(Collectors.toList());
-        assertThat(tableNames.size()).isEqualTo(1);
+        assertThat(tableNames).hasSize(1);
         assertThat(tableNames.get(0)).isEqualTo("address_shanghai");
     }
 
     @Test
-    public void testAddNewTableOneByOneSingleParallelism() throws Exception {
+    void testAddNewTableOneByOneSingleParallelism() throws Exception {
         TestParam testParam =
                 TestParam.newBuilder(
                                 Collections.singletonList("address_hangzhou"),
@@ -253,7 +253,7 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testAddNewTableOneByOne() throws Exception {
+    void testAddNewTableOneByOne() throws Exception {
         TestParam testParam =
                 TestParam.newBuilder(
                                 Collections.singletonList("address_hangzhou"),
@@ -268,7 +268,7 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testAddNewTableByPatternSingleParallelism() throws Exception {
+    void testAddNewTableByPatternSingleParallelism() throws Exception {
         TestParam testParam =
                 TestParam.newBuilder(
                                 Collections.singletonList("address_\\.*"),
@@ -285,7 +285,7 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testAddNewTableByPattern() throws Exception {
+    void testAddNewTableByPattern() throws Exception {
         TestParam testParam =
                 TestParam.newBuilder(
                                 Collections.singletonList("address_\\.*"),
@@ -351,6 +351,9 @@ public class MysqlPipelineNewlyAddedTableITCase extends MySqlSourceTestBase {
             initialAddressTables(getConnection(), testParam.getSecondRoundInitTables());
         }
 
+        // sleep 1s to wait for the assign status to INITIAL_ASSIGNING_FINISHED.
+        // Otherwise, the restart job won't read newly added tables, and this test will be stuck.
+        Thread.sleep(1000L);
         // step 4: trigger a savepoint and cancel the job
         finishedSavePointPath = triggerSavepointWithRetry(jobClient, savepointDirectory);
         jobClient.cancel().get();
