@@ -61,9 +61,10 @@ import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.ObjectMap
 import com.starrocks.connector.flink.table.data.StarRocksRowData;
 import com.starrocks.connector.flink.table.sink.StarRocksSinkOptions;
 import com.starrocks.connector.flink.table.sink.v2.DefaultStarRocksSinkContext;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.math.BigDecimal;
 import java.sql.Timestamp;
@@ -78,18 +79,15 @@ import java.util.OptionalLong;
 import java.util.SortedMap;
 import java.util.TreeMap;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-
 /**
  * Tests for {@link org.apache.flink.cdc.connectors.starrocks.sink.EventRecordSerializationSchema}.
  */
-public class EventRecordSerializationSchemaTest {
+class EventRecordSerializationSchemaTest {
 
     private EventRecordSerializationSchema serializer;
     private ObjectMapper objectMapper;
 
-    @Before
+    @BeforeEach
     public void setup() {
         this.serializer = new EventRecordSerializationSchema(ZoneId.of("+08"));
         this.serializer.open(
@@ -100,13 +98,13 @@ public class EventRecordSerializationSchemaTest {
         this.objectMapper = new ObjectMapper();
     }
 
-    @After
+    @AfterEach
     public void teardown() {
         this.serializer.close();
     }
 
     @Test
-    public void testMixedSchemaAndDataChanges() throws Exception {
+    void testMixedSchemaAndDataChanges() throws Exception {
         // 1. create table1, and insert/delete/update data
         TableId table1 = TableId.parse("test.tbl1");
         Schema schema1 =
@@ -117,7 +115,7 @@ public class EventRecordSerializationSchemaTest {
                         .primaryKey("col1")
                         .build();
         CreateTableEvent createTableEvent1 = new CreateTableEvent(table1, schema1);
-        assertNull(serializer.serialize(createTableEvent1));
+        Assertions.assertThat(serializer.serialize(createTableEvent1)).isNull();
 
         BinaryRecordDataGenerator generator1 =
                 new BinaryRecordDataGenerator(
@@ -184,7 +182,7 @@ public class EventRecordSerializationSchemaTest {
                         .primaryKey("col1")
                         .build();
         CreateTableEvent createTableEvent2 = new CreateTableEvent(table2, schema2);
-        assertNull(serializer.serialize(createTableEvent2));
+        Assertions.assertThat(serializer.serialize(createTableEvent2)).isNull();
 
         BinaryRecordDataGenerator generator2 =
                 new BinaryRecordDataGenerator(
@@ -219,7 +217,7 @@ public class EventRecordSerializationSchemaTest {
         BinaryRecordDataGenerator newGenerator1 =
                 new BinaryRecordDataGenerator(
                         newSchema1.getColumnDataTypes().toArray(new DataType[0]));
-        assertNull(serializer.serialize(addColumnEvent));
+        Assertions.assertThat(serializer.serialize(addColumnEvent)).isNull();
 
         DataChangeEvent deleteEvent2 =
                 DataChangeEvent.deleteEvent(
@@ -248,7 +246,7 @@ public class EventRecordSerializationSchemaTest {
         BinaryRecordDataGenerator newGenerator2 =
                 new BinaryRecordDataGenerator(
                         newSchema2.getColumnDataTypes().toArray(new DataType[0]));
-        assertNull(serializer.serialize(dropColumnEvent));
+        Assertions.assertThat(serializer.serialize(dropColumnEvent)).isNull();
 
         DataChangeEvent insertEvent3 =
                 DataChangeEvent.insertEvent(
@@ -264,17 +262,17 @@ public class EventRecordSerializationSchemaTest {
     private void verifySerializeResult(
             TableId expectTable, String expectRow, StarRocksRowData actualRowData)
             throws Exception {
-        assertEquals(expectTable.getSchemaName(), actualRowData.getDatabase());
-        assertEquals(expectTable.getTableName(), actualRowData.getTable());
-        SortedMap expectMap =
+        Assertions.assertThat(actualRowData.getDatabase()).isEqualTo(expectTable.getSchemaName());
+        Assertions.assertThat(actualRowData.getTable()).isEqualTo(expectTable.getTableName());
+        SortedMap<String, Object> expectMap =
                 objectMapper.readValue(expectRow, new TypeReference<TreeMap<String, Object>>() {});
-        SortedMap actualMap =
+        SortedMap<String, Object> actualMap =
                 actualRowData.getRow() == null
                         ? null
                         : objectMapper.readValue(
                                 actualRowData.getRow(),
                                 new TypeReference<TreeMap<String, Object>>() {});
-        assertEquals(expectMap, actualMap);
+        Assertions.assertThat(actualMap).isEqualTo(expectMap);
     }
 
     /** A mock context for serialization schema testing. */
