@@ -46,17 +46,16 @@ import org.apache.flink.cdc.composer.flink.translator.SchemaOperatorTranslator;
 import org.apache.flink.cdc.connectors.starrocks.sink.utils.StarRocksContainer;
 import org.apache.flink.cdc.connectors.starrocks.sink.utils.StarRocksSinkTestBase;
 import org.apache.flink.cdc.runtime.typeutils.BinaryRecordDataGenerator;
-import org.apache.flink.runtime.client.JobExecutionException;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 
 import com.mysql.jdbc.exceptions.jdbc4.MySQLSyntaxErrorException;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -71,18 +70,18 @@ import static org.apache.flink.cdc.connectors.starrocks.sink.StarRocksDataSinkOp
 import static org.apache.flink.cdc.connectors.starrocks.sink.StarRocksDataSinkOptions.USERNAME;
 
 /** IT tests for {@link StarRocksMetadataApplier}. */
-public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
+class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
     private static final StreamExecutionEnvironment env =
             StreamExecutionEnvironment.getExecutionEnvironment();
 
-    @BeforeClass
+    @BeforeAll
     public static void before() {
         env.setParallelism(DEFAULT_PARALLELISM);
         env.enableCheckpointing(3000);
         env.setRestartStrategy(RestartStrategies.noRestart());
     }
 
-    @Before
+    @BeforeEach
     public void initializeDatabase() {
         executeSql(
                 String.format(
@@ -91,7 +90,7 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
         LOG.info("Database {} created.", StarRocksContainer.STARROCKS_DATABASE_NAME);
     }
 
-    @After
+    @AfterEach
     public void destroyDatabase() {
         executeSql(String.format("DROP DATABASE %s;", StarRocksContainer.STARROCKS_DATABASE_NAME));
         LOG.info("Database {} destroyed.", StarRocksContainer.STARROCKS_DATABASE_NAME);
@@ -190,7 +189,7 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
     }
 
     @Test
-    public void testStarRocksDataType() throws Exception {
+    void testStarRocksDataType() throws Exception {
         TableId tableId =
                 TableId.tableId(
                         StarRocksContainer.STARROCKS_DATABASE_NAME,
@@ -266,7 +265,7 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
     }
 
     @Test
-    public void testStarRocksAddColumn() throws Exception {
+    void testStarRocksAddColumn() throws Exception {
         TableId tableId =
                 TableId.tableId(
                         StarRocksContainer.STARROCKS_DATABASE_NAME,
@@ -289,7 +288,7 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
     }
 
     @Test
-    public void testStarRocksDropColumn() throws Exception {
+    void testStarRocksDropColumn() throws Exception {
         TableId tableId =
                 TableId.tableId(
                         StarRocksContainer.STARROCKS_DATABASE_NAME,
@@ -307,8 +306,8 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
     }
 
     @Test
-    @Ignore("Rename column is not supported currently.")
-    public void testStarRocksRenameColumn() throws Exception {
+    @Disabled("Rename column is not supported currently.")
+    void testStarRocksRenameColumn() throws Exception {
         TableId tableId =
                 TableId.tableId(
                         StarRocksContainer.STARROCKS_DATABASE_NAME,
@@ -328,8 +327,8 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
     }
 
     @Test
-    @Ignore("Alter column type is not supported currently.")
-    public void testStarRocksAlterColumnType() throws Exception {
+    @Disabled("Alter column type is not supported currently.")
+    void testStarRocksAlterColumnType() throws Exception {
         TableId tableId =
                 TableId.tableId(
                         StarRocksContainer.STARROCKS_DATABASE_NAME,
@@ -348,15 +347,18 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
         assertEqualsInOrder(expected, actual);
     }
 
-    @Test(expected = JobExecutionException.class)
-    @Ignore("Alter column type is not supported currently.")
-    public void testStarRocksNarrowingAlterColumnType() throws Exception {
-        TableId tableId =
-                TableId.tableId(
-                        StarRocksContainer.STARROCKS_DATABASE_NAME,
-                        StarRocksContainer.STARROCKS_TABLE_NAME);
+    @Test
+    @Disabled("Alter column type is not supported currently.")
+    void testStarRocksNarrowingAlterColumnType() throws Exception {
+        Assertions.assertThatThrownBy(
+                () -> {
+                    TableId tableId =
+                            TableId.tableId(
+                                    StarRocksContainer.STARROCKS_DATABASE_NAME,
+                                    StarRocksContainer.STARROCKS_TABLE_NAME);
 
-        runJobWithEvents(generateNarrowingAlterColumnTypeEvents(tableId));
+                    runJobWithEvents(generateNarrowingAlterColumnTypeEvents(tableId));
+                });
     }
 
     @Test
@@ -412,12 +414,12 @@ public class StarRocksMetadataApplierITCase extends StarRocksSinkTestBase {
                         new DropTableEvent(tableId));
         runJobWithEvents(dropTableTestingEvents);
 
-        Assert.assertThrows(
-                String.format(
-                        "Getting analyzing error. Detail message: Unknown table '%s.%s'.",
-                        tableId.getSchemaName(), tableId.getTableName()),
-                MySQLSyntaxErrorException.class,
-                () -> fetchTableContent(tableId, 3));
+        Assertions.assertThatThrownBy(() -> fetchTableContent(tableId, 3))
+                .isExactlyInstanceOf(MySQLSyntaxErrorException.class)
+                .hasMessageContaining(
+                        String.format(
+                                "Getting analyzing error. Detail message: Unknown table '%s.%s'.",
+                                tableId.getSchemaName(), tableId.getTableName()));
     }
 
     private void runJobWithEvents(List<Event> events) throws Exception {
