@@ -38,7 +38,8 @@ import org.apache.flink.util.Preconditions;
 
 import com.jayway.jsonpath.JsonPath;
 import org.apache.kafka.connect.source.SourceRecord;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import javax.annotation.Nullable;
 
@@ -60,16 +61,13 @@ import static org.apache.flink.cdc.connectors.utils.AssertUtils.assertDelete;
 import static org.apache.flink.cdc.connectors.utils.AssertUtils.assertInsert;
 import static org.apache.flink.cdc.connectors.utils.AssertUtils.assertRead;
 import static org.apache.flink.cdc.connectors.utils.AssertUtils.assertUpdate;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
 import static org.testcontainers.containers.Db2Container.DB2_PORT;
 
 /** Test for {@link Db2Source} which also heavily tests {@link DebeziumSourceFunction}. */
-public class Db2SourceTest extends Db2TestBase {
+class Db2SourceTest extends Db2TestBase {
 
     @Test
-    public void testConsumingAllEvents() throws Exception {
+    void testConsumingAllEvents() throws Exception {
         initializeDb2Table("inventory", "PRODUCTS");
         DebeziumSourceFunction<SourceRecord> source = createDb2Source("DB2INST1.PRODUCTS");
         TestSourceContext<SourceRecord> sourceContext = new TestSourceContext<>();
@@ -89,7 +87,7 @@ public class Db2SourceTest extends Db2TestBase {
             runThread.start();
 
             List<SourceRecord> records = drain(sourceContext, 9);
-            assertEquals(9, records.size());
+            Assertions.assertThat(records).hasSize(9);
             for (int i = 0; i < records.size(); i++) {
                 assertRead(records.get(i), "ID", 101 + i);
             }
@@ -139,7 +137,7 @@ public class Db2SourceTest extends Db2TestBase {
     }
 
     @Test
-    public void testCheckpointAndRestore() throws Exception {
+    void testCheckpointAndRestore() throws Exception {
         initializeDb2Table("inventory", "PRODUCTS");
         final TestingListState<byte[]> offsetState = new TestingListState<>();
         final TestingListState<String> historyState = new TestingListState<>();
@@ -167,22 +165,23 @@ public class Db2SourceTest extends Db2TestBase {
 
             // wait until consumer is started
             int received = drain(sourceContext, 2).size();
-            assertEquals(2, received);
+            Assertions.assertThat(received).isEqualTo(2);
 
             // we can't perform checkpoint during DB snapshot
-            assertFalse(
-                    waitForCheckpointLock(
-                            sourceContext.getCheckpointLock(), Duration.ofSeconds(3)));
+            Assertions.assertThat(
+                            waitForCheckpointLock(
+                                    sourceContext.getCheckpointLock(), Duration.ofSeconds(3)))
+                    .isFalse();
 
             // unblock the source context to continue the processing
             sourceContext.blocker.release();
             // wait until the source finishes the database snapshot
             List<SourceRecord> records = drain(sourceContext, 9 - received);
-            assertEquals(9, records.size() + received);
+            Assertions.assertThat(records.size() + received).isEqualTo(9);
 
             // state is still empty
-            assertEquals(0, offsetState.list.size());
-            assertEquals(0, historyState.list.size());
+            Assertions.assertThat(offsetState.list).isEmpty();
+            Assertions.assertThat(historyState.list).isEmpty();
 
             // ---------------------------------------------------------------------------
             // Step-2: trigger checkpoint-1 after snapshot finished
@@ -192,12 +191,13 @@ public class Db2SourceTest extends Db2TestBase {
                 source.snapshotState(new StateSnapshotContextSynchronousImpl(101, 101));
             }
 
-            assertEquals(1, offsetState.list.size());
+            Assertions.assertThat(offsetState.list).hasSize(1);
             String state = new String(offsetState.list.get(0), StandardCharsets.UTF_8);
-            assertEquals("db2_cdc_source", JsonPath.read(state, "$.sourcePartition.server"));
+            Assertions.assertThat(JsonPath.<String>read(state, "$.sourcePartition.server"))
+                    .isEqualTo("db2_cdc_source");
 
             String lsn = JsonPath.read(state, "$.sourceOffset.commit_lsn");
-            assertTrue(lsn.compareTo(prevLsn) > 0);
+            Assertions.assertThat(lsn).isGreaterThan(prevLsn);
             prevLsn = lsn;
 
             source.close();
@@ -222,7 +222,8 @@ public class Db2SourceTest extends Db2TestBase {
             runThread2.start();
 
             // make sure there is no more events
-            assertFalse(waitForAvailableRecords(Duration.ofSeconds(5), sourceContext2));
+            Assertions.assertThat(waitForAvailableRecords(Duration.ofSeconds(5), sourceContext2))
+                    .isFalse();
 
             try (Connection connection = getJdbcConnection();
                     Statement statement = connection.createStatement()) {
@@ -230,7 +231,7 @@ public class Db2SourceTest extends Db2TestBase {
                 statement.execute(
                         "INSERT INTO DB2INST1.PRODUCTS VALUES (default,'robot','Toy robot',1.304)"); // 110
                 List<SourceRecord> records = drain(sourceContext2, 1);
-                assertEquals(1, records.size());
+                Assertions.assertThat(records).hasSize(1);
                 assertInsert(records.get(0), "ID", 110);
 
                 // ---------------------------------------------------------------------------
@@ -241,11 +242,12 @@ public class Db2SourceTest extends Db2TestBase {
                     source2.snapshotState(new StateSnapshotContextSynchronousImpl(138, 138));
                 }
 
-                assertEquals(1, offsetState.list.size());
+                Assertions.assertThat(offsetState.list).hasSize(1);
                 String state = new String(offsetState.list.get(0), StandardCharsets.UTF_8);
-                assertEquals("db2_cdc_source", JsonPath.read(state, "$.sourcePartition.server"));
+                Assertions.assertThat(JsonPath.<String>read(state, "$.sourcePartition.server"))
+                        .isEqualTo("db2_cdc_source");
                 String lsn = JsonPath.read(state, "$.sourceOffset.commit_lsn");
-                assertTrue(lsn.compareTo(prevLsn) > 0);
+                Assertions.assertThat(lsn).isGreaterThan(prevLsn);
 
                 // execute 2 more DMLs to have more redo logs
                 statement.execute(
@@ -283,7 +285,8 @@ public class Db2SourceTest extends Db2TestBase {
             assertUpdate(records.get(1), "ID", 1001);
 
             // make sure there is no more events
-            assertFalse(waitForAvailableRecords(Duration.ofSeconds(3), sourceContext3));
+            Assertions.assertThat(waitForAvailableRecords(Duration.ofSeconds(3), sourceContext3))
+                    .isFalse();
 
             // can continue to receive new events
             try (Connection connection = getJdbcConnection();
@@ -300,11 +303,12 @@ public class Db2SourceTest extends Db2TestBase {
                 // checkpoint 3
                 source3.snapshotState(new StateSnapshotContextSynchronousImpl(233, 233));
             }
-            assertEquals(1, offsetState.list.size());
+            Assertions.assertThat(offsetState.list).hasSize(1);
             String state = new String(offsetState.list.get(0), StandardCharsets.UTF_8);
-            assertEquals("db2_cdc_source", JsonPath.read(state, "$.sourcePartition.server"));
+            Assertions.assertThat(JsonPath.<String>read(state, "$.sourcePartition.server"))
+                    .isEqualTo("db2_cdc_source");
             String lsn = JsonPath.read(state, "$.sourceOffset.commit_lsn");
-            assertTrue(lsn.compareTo(prevLsn) > 0);
+            Assertions.assertThat(lsn).isGreaterThan(prevLsn);
 
             source3.close();
             runThread3.sync();
