@@ -24,6 +24,8 @@ import org.apache.flink.table.data.RowData;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
 import org.apache.flink.types.Row;
 
+import org.assertj.core.api.Assertions;
+
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -31,8 +33,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
-import static org.junit.Assert.fail;
-
 /** MongoDB test utilities. */
 public class MongoDBTestUtils {
 
@@ -53,7 +53,7 @@ public class MongoDBTestUtils {
         long deadline = System.nanoTime() + timeUnit.toNanos(timeout);
         while (sinkSize(sinkName) < expectedSize) {
             if (System.nanoTime() > deadline) {
-                fail(
+                Assertions.fail(
                         "Wait for sink size timeout, raw results: \n"
                                 + String.join(
                                         "\n",
