@@ -42,7 +42,6 @@ import org.apache.flink.cdc.connectors.mysql.testutils.UniqueDatabase;
 import org.apache.flink.core.testutils.CommonTestUtils;
 import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.types.DataType;
-import org.apache.flink.util.ExceptionUtils;
 
 import com.github.shyiko.mysql.binlog.BinaryLogClient;
 import com.github.shyiko.mysql.binlog.event.Event;
@@ -60,10 +59,11 @@ import io.debezium.relational.history.TableChanges;
 import io.debezium.relational.history.TableChanges.TableChange;
 import org.apache.kafka.connect.data.Struct;
 import org.apache.kafka.connect.source.SourceRecord;
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.testcontainers.lifecycle.Startables;
 
 import java.sql.Connection;
@@ -88,13 +88,9 @@ import static org.apache.flink.cdc.connectors.mysql.source.utils.RecordUtils.get
 import static org.apache.flink.cdc.connectors.mysql.source.utils.RecordUtils.getStartingOffsetOfBinlogSplit;
 import static org.apache.flink.cdc.connectors.mysql.testutils.MetricsUtils.getMySqlSplitEnumeratorContext;
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertThrows;
-import static org.junit.Assert.assertTrue;
 
 /** Tests for {@link org.apache.flink.cdc.connectors.mysql.debezium.reader.BinlogSplitReader}. */
-public class BinlogSplitReaderTest extends MySqlSourceTestBase {
+class BinlogSplitReaderTest extends MySqlSourceTestBase {
     private static final String TEST_USER = "mysqluser";
     private static final String TEST_PASSWORD = "mysqlpw";
     private static final Duration DEFAULT_TIMEOUT = Duration.ofSeconds(30);
@@ -115,21 +111,21 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     private BinaryLogClient binaryLogClient;
     private MySqlConnection mySqlConnection;
 
-    @BeforeClass
+    @BeforeAll
     public static void beforeClass() {
         LOG.info("Starting MySql8 containers...");
         Startables.deepStart(Stream.of(MYSQL8_CONTAINER)).join();
         LOG.info("Container MySql8 is started.");
     }
 
-    @AfterClass
+    @AfterAll
     public static void afterClass() {
         LOG.info("Stopping MySql8 containers...");
         MYSQL8_CONTAINER.stop();
         LOG.info("Container MySql8 is stopped.");
     }
 
-    @After
+    @AfterEach
     public void after() throws Exception {
         if (mySqlConnection != null) {
             mySqlConnection.close();
@@ -141,7 +137,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadSingleBinlogSplit() throws Exception {
+    void testReadSingleBinlogSplit() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig = getConfig(new String[] {"customers_even_dist"});
         binaryLogClient = DebeziumUtils.createBinaryClient(sourceConfig.getDbzConfiguration());
@@ -180,7 +176,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadAllBinlogSplitsForOneTable() throws Exception {
+    void testReadAllBinlogSplitsForOneTable() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig = getConfig(new String[] {"customers_even_dist"});
         binaryLogClient = DebeziumUtils.createBinaryClient(sourceConfig.getDbzConfiguration());
@@ -228,7 +224,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadAllBinlogForTableWithSingleLine() throws Exception {
+    void testReadAllBinlogForTableWithSingleLine() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig = getConfig(new String[] {"customer_card_single_line"});
         binaryLogClient = DebeziumUtils.createBinaryClient(sourceConfig.getDbzConfiguration());
@@ -263,7 +259,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadAllBinlogSplitsForTables() throws Exception {
+    void testReadAllBinlogSplitsForTables() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig =
                 getConfig(new String[] {"customer_card", "customer_card_single_line"});
@@ -320,7 +316,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromLatestOffset() throws Exception {
+    void testReadBinlogFromLatestOffset() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig =
                 getConfig(StartupOptions.latest(), new String[] {"customers"});
@@ -363,7 +359,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromEarliestOffset() throws Exception {
+    void testReadBinlogFromEarliestOffset() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig =
                 getConfig(StartupOptions.earliest(), new String[] {"customers"});
@@ -427,7 +423,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromEarliestOffsetAfterSchemaChange() throws Exception {
+    void testReadBinlogFromEarliestOffsetAfterSchemaChange() throws Exception {
         customerDatabase.createAndInitialize();
         MySqlSourceConfig sourceConfig =
                 getConfig(StartupOptions.earliest(), new String[] {"customers"});
@@ -451,22 +447,17 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
 
         // An exception is expected here because the table schema is changed, which is not allowed
         // under earliest startup mode.
-        Throwable throwable =
-                assertThrows(Throwable.class, () -> readBinlogSplits(dataType, reader, 1));
-        Optional<SchemaOutOfSyncException> schemaOutOfSyncException =
-                ExceptionUtils.findThrowable(throwable, SchemaOutOfSyncException.class);
-
-        reader.close();
-        assertTrue(schemaOutOfSyncException.isPresent());
-        assertEquals(
-                "Internal schema representation is probably out of sync with real database schema. "
-                        + "The reason could be that the table schema was changed after the starting "
-                        + "binlog offset, which is not supported when startup mode is set to EARLIEST_OFFSET",
-                schemaOutOfSyncException.get().getMessage());
+        Assertions.assertThatThrownBy(() -> readBinlogSplits(dataType, reader, 1))
+                .cause()
+                .isExactlyInstanceOf(SchemaOutOfSyncException.class)
+                .hasMessage(
+                        "Internal schema representation is probably out of sync with real database schema. "
+                                + "The reason could be that the table schema was changed after the starting "
+                                + "binlog offset, which is not supported when startup mode is set to EARLIEST_OFFSET");
     }
 
     @Test
-    public void testReadBinlogFromBinlogFilePosition() throws Exception {
+    void testReadBinlogFromBinlogFilePosition() throws Exception {
         // Preparations
         customerDatabase.createAndInitialize();
         MySqlSourceConfig connectionConfig = getConfig(new String[] {"customers"});
@@ -520,7 +511,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testSkippingEvents() throws Exception {
+    void testSkippingEvents() throws Exception {
         // Preparations
         customerDatabase.createAndInitialize();
         MySqlSourceConfig connectionConfig = getConfig(new String[] {"customers"});
@@ -575,7 +566,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromGtidSet() throws Exception {
+    void testReadBinlogFromGtidSet() throws Exception {
         // Preparations
         customerDatabase.createAndInitialize();
         MySqlSourceConfig connectionConfig = getConfig(new String[] {"customers"});
@@ -628,7 +619,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromTimestamp() throws Exception {
+    void testReadBinlogFromTimestamp() throws Exception {
         // Preparations
         customerDatabase.createAndInitialize();
         MySqlSourceConfig connectionConfig = getConfig(new String[] {"customers"});
@@ -683,7 +674,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromTimestampAfterSchemaChange() throws Exception {
+    void testReadBinlogFromTimestampAfterSchemaChange() throws Exception {
         // Preparations
         customerDatabase.createAndInitialize();
         MySqlSourceConfig connectionConfig = getConfig(new String[] {"customers"});
@@ -743,7 +734,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testHeartbeatEvent() throws Exception {
+    void testHeartbeatEvent() throws Exception {
         // Initialize database
         customerDatabase.createAndInitialize();
 
@@ -794,7 +785,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testReadBinlogFromUnavailableBinlog() throws Exception {
+    void testReadBinlogFromUnavailableBinlog() throws Exception {
         // Preparations
         inventoryDatabase8.createAndInitialize();
         MySqlSourceConfig connectionConfig =
@@ -853,7 +844,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
     }
 
     @Test
-    public void testRestoreFromCheckpointWithTimestampStartingOffset() throws Exception {
+    void testRestoreFromCheckpointWithTimestampStartingOffset() throws Exception {
         // Preparations
         inventoryDatabase8.createAndInitialize();
         MySqlSourceConfig connectionConfig =
@@ -956,7 +947,7 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
         List<SourceRecord> sourceRecords =
                 pollRecordsFromReader(binlogReader, RecordUtils::isDataChangeRecord);
         MYSQL_CONTAINER_NOGTID.stop();
-        assertTrue(sourceRecords.isEmpty());
+        Assertions.assertThat(sourceRecords).isEmpty();
     }
 
     private BinlogSplitReader createBinlogReader(MySqlSourceConfig sourceConfig) {
@@ -1082,8 +1073,8 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
         }
         snapshotSplitReader.close();
 
-        assertNotNull(snapshotSplitReader.getExecutorService());
-        assertTrue(snapshotSplitReader.getExecutorService().isTerminated());
+        Assertions.assertThat(snapshotSplitReader.getExecutorService()).isNotNull();
+        Assertions.assertThat(snapshotSplitReader.getExecutorService().isTerminated()).isTrue();
 
         // step-2: create binlog split according the finished snapshot splits
         List<FinishedSnapshotSplitInfo> finishedSplitsInfo =
@@ -1128,8 +1119,8 @@ public class BinlogSplitReaderTest extends MySqlSourceTestBase {
         }
         binlogReader.close();
 
-        assertNotNull(binlogReader.getExecutorService());
-        assertTrue(binlogReader.getExecutorService().isTerminated());
+        Assertions.assertThat(binlogReader.getExecutorService()).isNotNull();
+        Assertions.assertThat(binlogReader.getExecutorService().isTerminated()).isTrue();
 
         return actual;
     }
