@@ -249,6 +249,15 @@ public class OracleSourceBuilder<T> {
         return this;
     }
 
+    /**
+     * Whether the {@link OracleIncrementalSource} should assign the unbounded chunks first or not
+     * during snapshot reading phase.
+     */
+    public OracleSourceBuilder<T> assignUnboundedChunkFirst(boolean assignUnboundedChunkFirst) {
+        this.configFactory.assignUnboundedChunkFirst(assignUnboundedChunkFirst);
+        return this;
+    }
+
     /**
      * Build the {@link OracleIncrementalSource}.
      *
