@@ -21,6 +21,7 @@ import org.apache.flink.api.common.restartstrategy.RestartStrategies;
 import org.apache.flink.cdc.connectors.postgres.PostgresTestBase;
 import org.apache.flink.cdc.connectors.postgres.testutils.PostgresTestUtils;
 import org.apache.flink.cdc.connectors.postgres.testutils.UniqueDatabase;
+import org.apache.flink.cdc.connectors.utils.ExternalResourceProxy;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.execution.JobClient;
 import org.apache.flink.runtime.checkpoint.CheckpointException;
@@ -36,13 +37,14 @@ import org.apache.flink.util.ExceptionUtils;
 
 import io.debezium.connector.postgresql.connection.PostgresConnection;
 import io.debezium.jdbc.JdbcConnection;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.rules.Timeout;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.api.io.TempDir;
 
+import java.nio.file.Path;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -62,22 +64,25 @@ import static java.lang.String.format;
  * IT tests to cover various newly added tables during capture process. Ignore this test because
  * this test will pass until close
  */
-public class NewlyAddedTableITCase extends PostgresTestBase {
-    @Rule public final Timeout timeoutPerTest = Timeout.seconds(300);
+@Timeout(value = 300, unit = TimeUnit.SECONDS)
+class NewlyAddedTableITCase extends PostgresTestBase {
 
     private static final String DB_NAME_PREFIX = "postgres";
     private static final String SCHEMA_NAME = "customer";
     protected static final int DEFAULT_PARALLELISM = 4;
 
-    @Rule
-    public final MiniClusterWithClientResource miniClusterResource =
-            new MiniClusterWithClientResource(
-                    new MiniClusterResourceConfiguration.Builder()
-                            .setNumberTaskManagers(1)
-                            .setNumberSlotsPerTaskManager(DEFAULT_PARALLELISM)
-                            .setRpcServiceSharing(RpcServiceSharing.DEDICATED)
-                            .withHaLeadershipControl()
-                            .build());
+    @TempDir private Path tempDir;
+
+    @RegisterExtension
+    public final ExternalResourceProxy<MiniClusterWithClientResource> miniClusterResource =
+            new ExternalResourceProxy<>(
+                    new MiniClusterWithClientResource(
+                            new MiniClusterResourceConfiguration.Builder()
+                                    .setNumberTaskManagers(1)
+                                    .setNumberSlotsPerTaskManager(DEFAULT_PARALLELISM)
+                                    .setRpcServiceSharing(RpcServiceSharing.DEDICATED)
+                                    .withHaLeadershipControl()
+                                    .build()));
 
     private final UniqueDatabase customDatabase =
             new UniqueDatabase(
@@ -90,7 +95,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     private String slotName;
     private final ScheduledExecutorService mockWalLogExecutor = Executors.newScheduledThreadPool(1);
 
-    @Before
+    @BeforeEach
     public void before() throws SQLException {
         TestValuesTableFactory.clearAllData();
         customDatabase.createAndInitialize();
@@ -123,7 +128,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
         this.slotName = getSlotName();
     }
 
-    @After
+    @AfterEach
     public void after() throws Exception {
         mockWalLogExecutor.shutdown();
         // sleep 1000ms to wait until connections are closed.
@@ -142,7 +147,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineOnce() throws Exception {
+    void testNewlyAddedTableForExistsPipelineOnce() throws Exception {
         testNewlyAddedTableOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.NONE,
@@ -153,7 +158,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineOnceWithAheadWalLog() throws Exception {
+    void testNewlyAddedTableForExistsPipelineOnceWithAheadWalLog() throws Exception {
         testNewlyAddedTableOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.NONE,
@@ -164,7 +169,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineTwice() throws Exception {
+    void testNewlyAddedTableForExistsPipelineTwice() throws Exception {
         testNewlyAddedTableOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.NONE,
@@ -176,7 +181,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineTwiceWithAheadWalLog() throws Exception {
+    void testNewlyAddedTableForExistsPipelineTwiceWithAheadWalLog() throws Exception {
         testNewlyAddedTableOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.NONE,
@@ -188,7 +193,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineTwiceWithAheadWalLogAndAutoCloseReader()
+    void testNewlyAddedTableForExistsPipelineTwiceWithAheadWalLogAndAutoCloseReader()
             throws Exception {
         Map<String, String> otherOptions = new HashMap<>();
         otherOptions.put("scan.incremental.close-idle-reader.enabled", "true");
@@ -204,7 +209,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineThrice() throws Exception {
+    void testNewlyAddedTableForExistsPipelineThrice() throws Exception {
         testNewlyAddedTableOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.NONE,
@@ -217,7 +222,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineThriceWithAheadWalLog() throws Exception {
+    void testNewlyAddedTableForExistsPipelineThriceWithAheadWalLog() throws Exception {
         testNewlyAddedTableOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.NONE,
@@ -230,7 +235,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineSingleParallelism() throws Exception {
+    void testNewlyAddedTableForExistsPipelineSingleParallelism() throws Exception {
         testNewlyAddedTableOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.NONE,
@@ -241,8 +246,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testNewlyAddedTableForExistsPipelineSingleParallelismWithAheadWalLog()
-            throws Exception {
+    void testNewlyAddedTableForExistsPipelineSingleParallelismWithAheadWalLog() throws Exception {
         testNewlyAddedTableOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.NONE,
@@ -253,7 +257,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForNewlyAddedTable() throws Exception {
+    void testJobManagerFailoverForNewlyAddedTable() throws Exception {
         testNewlyAddedTableOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.JM,
@@ -264,7 +268,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForNewlyAddedTableWithAheadWalLog() throws Exception {
+    void testJobManagerFailoverForNewlyAddedTableWithAheadWalLog() throws Exception {
         testNewlyAddedTableOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.JM,
@@ -275,7 +279,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForNewlyAddedTable() throws Exception {
+    void testTaskManagerFailoverForNewlyAddedTable() throws Exception {
         testNewlyAddedTableOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.TM,
@@ -286,7 +290,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForNewlyAddedTableWithAheadWalLog() throws Exception {
+    void testTaskManagerFailoverForNewlyAddedTableWithAheadWalLog() throws Exception {
         testNewlyAddedTableOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.TM,
@@ -297,7 +301,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForRemoveTableSingleParallelism() throws Exception {
+    void testJobManagerFailoverForRemoveTableSingleParallelism() throws Exception {
         testRemoveTablesOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.JM,
@@ -308,7 +312,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testJobManagerFailoverForRemoveTable() throws Exception {
+    void testJobManagerFailoverForRemoveTable() throws Exception {
         testRemoveTablesOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.JM,
@@ -319,7 +323,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForRemoveTableSingleParallelism() throws Exception {
+    void testTaskManagerFailoverForRemoveTableSingleParallelism() throws Exception {
         testRemoveTablesOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.TM,
@@ -330,7 +334,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testTaskManagerFailoverForRemoveTable() throws Exception {
+    void testTaskManagerFailoverForRemoveTable() throws Exception {
         testRemoveTablesOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.TM,
@@ -341,7 +345,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testRemoveTableSingleParallelism() throws Exception {
+    void testRemoveTableSingleParallelism() throws Exception {
         testRemoveTablesOneByOne(
                 1,
                 PostgresTestUtils.FailoverType.NONE,
@@ -352,7 +356,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testRemoveTable() throws Exception {
+    void testRemoveTable() throws Exception {
         testRemoveTablesOneByOne(
                 DEFAULT_PARALLELISM,
                 PostgresTestUtils.FailoverType.NONE,
@@ -363,7 +367,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
     }
 
     @Test
-    public void testRemoveAndAddTablesOneByOne() throws Exception {
+    void testRemoveAndAddTablesOneByOne() throws Exception {
         testRemoveAndAddTablesOneByOne(
                 1, "address_hangzhou", "address_beijing", "address_shanghai");
     }
@@ -375,9 +379,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
         // step 1: create postgresql tables with all tables included
         initialAddressTables(connection, captureAddressTables);
 
-        final TemporaryFolder temporaryFolder = new TemporaryFolder();
-        temporaryFolder.create();
-        final String savepointDirectory = temporaryFolder.newFolder().toURI().toString();
+        final String savepointDirectory = tempDir.toString();
 
         // get all expected data
         List<String> fetchedDataList = new ArrayList<>();
@@ -468,9 +470,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
         // step 1: create postgresql tables with all tables included
         initialAddressTables(getConnection(), captureAddressTables);
 
-        final TemporaryFolder temporaryFolder = new TemporaryFolder();
-        temporaryFolder.create();
-        final String savepointDirectory = temporaryFolder.newFolder().toURI().toString();
+        final String savepointDirectory = tempDir.toString();
 
         // get all expected data
         List<String> fetchedDataList = new ArrayList<>();
@@ -519,12 +519,16 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
                 PostgresTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
             waitForSinkSize("sink", fetchedDataList.size());
             assertEqualsInAnyOrder(
                     fetchedDataList, TestValuesTableFactory.getRawResultsAsStrings("sink"));
+            // sleep 1s to wait for the assign status to INITIAL_ASSIGNING_FINISHED.
+            // Otherwise, the restart job won't read newly added tables, and this test will be
+            // stuck.
+            Thread.sleep(1000L);
             finishedSavePointPath = triggerSavepointWithRetry(jobClient, savepointDirectory);
             jobClient.cancel().get();
         }
@@ -599,7 +603,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
                 PostgresTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
 
@@ -643,9 +647,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
         // step 1: create postgres tables with initial data
         initialAddressTables(getConnection(), captureAddressTables);
 
-        final TemporaryFolder temporaryFolder = new TemporaryFolder();
-        temporaryFolder.create();
-        final String savepointDirectory = temporaryFolder.newFolder().toURI().toString();
+        final String savepointDirectory = tempDir.toString();
 
         // test newly added table one by one
         String finishedSavePointPath = null;
@@ -716,13 +718,15 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
                 PostgresTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
             fetchedDataList.addAll(expectedSnapshotDataThisRound);
             PostgresTestUtils.waitForUpsertSinkSize("sink", fetchedDataList.size());
             assertEqualsInAnyOrder(
                     fetchedDataList, TestValuesTableFactory.getResultsAsStrings("sink"));
+            // Wait 1s until snapshot phase finished, make sure the binlog data is not lost.
+            Thread.sleep(1000L);
 
             // step 3: make some wal log data for this round
             makeFirstPartWalLogForAddressTable(getConnection(), newlyAddedTable);
@@ -730,7 +734,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
                 PostgresTestUtils.triggerFailover(
                         failoverType,
                         jobClient.getJobID(),
-                        miniClusterResource.getMiniCluster(),
+                        miniClusterResource.get().getMiniCluster(),
                         () -> sleepMs(100));
             }
             makeSecondPartWalLogForAddressTable(getConnection(), newlyAddedTable);
@@ -940,6 +944,7 @@ public class NewlyAddedTableITCase extends PostgresTestBase {
                         + " 'username' = '%s',"
                         + " 'password' = '%s',"
                         + " 'database-name' = '%s',"
+                        + " 'decoding.plugin.name' = 'pgoutput', "
                         + " 'schema-name' = '%s',"
                         + " 'table-name' = '%s',"
                         + " 'slot.name' = '%s', "
