@@ -21,6 +21,7 @@ import org.apache.flink.api.common.eventtime.WatermarkStrategy;
 import org.apache.flink.cdc.connectors.base.source.jdbc.JdbcIncrementalSource;
 import org.apache.flink.cdc.connectors.postgres.PostgresTestBase;
 import org.apache.flink.cdc.connectors.postgres.testutils.UniqueDatabase;
+import org.apache.flink.cdc.connectors.utils.ExternalResourceProxy;
 import org.apache.flink.cdc.debezium.DebeziumDeserializationSchema;
 import org.apache.flink.cdc.debezium.JsonDebeziumDeserializationSchema;
 import org.apache.flink.cdc.debezium.table.RowDataDebeziumDeserializeSchema;
@@ -40,9 +41,11 @@ import org.apache.flink.util.CloseableIterator;
 
 import io.debezium.connector.postgresql.connection.PostgresConnection;
 import io.debezium.connector.postgresql.spi.SlotState;
-import org.junit.Ignore;
-import org.junit.Rule;
-import org.junit.Test;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.sql.SQLException;
 import java.util.ArrayList;
@@ -56,27 +59,30 @@ import java.util.stream.Collectors;
 import static org.testcontainers.containers.PostgreSQLContainer.POSTGRESQL_PORT;
 
 /** Tests for Postgres Source based on incremental snapshot framework . */
-public class PostgresSourceExampleTest extends PostgresTestBase {
+class PostgresSourceExampleTest extends PostgresTestBase {
+
+    private static final Logger LOG = LoggerFactory.getLogger(PostgresSourceExampleTest.class);
 
     private static final String DB_NAME_PREFIX = "postgres";
     private static final String SCHEMA_NAME = "inventory";
     private static final String TABLE_ID = SCHEMA_NAME + ".products";
 
     private static final String SLOT_NAME = "flink";
-    private static final String PLUGIN_NAME = "decoderbufs";
+    private static final String PLUGIN_NAME = "pgoutput";
     private static final long CHECKPOINT_INTERVAL_MS = 3000;
 
     private static final int DEFAULT_PARALLELISM = 2;
 
-    @Rule
-    public final MiniClusterWithClientResource miniClusterResource =
-            new MiniClusterWithClientResource(
-                    new MiniClusterResourceConfiguration.Builder()
-                            .setNumberTaskManagers(1)
-                            .setNumberSlotsPerTaskManager(DEFAULT_PARALLELISM)
-                            .setRpcServiceSharing(RpcServiceSharing.DEDICATED)
-                            .withHaLeadershipControl()
-                            .build());
+    @RegisterExtension
+    public final ExternalResourceProxy<MiniClusterWithClientResource> miniClusterResource =
+            new ExternalResourceProxy<>(
+                    new MiniClusterWithClientResource(
+                            new MiniClusterResourceConfiguration.Builder()
+                                    .setNumberTaskManagers(1)
+                                    .setNumberSlotsPerTaskManager(DEFAULT_PARALLELISM)
+                                    .setRpcServiceSharing(RpcServiceSharing.DEDICATED)
+                                    .withHaLeadershipControl()
+                                    .build()));
 
     // 9 records in the inventory.products table
     private final UniqueDatabase inventoryDatabase =
@@ -88,8 +94,8 @@ public class PostgresSourceExampleTest extends PostgresTestBase {
                     POSTGRES_CONTAINER.getPassword());
 
     @Test
-    @Ignore("Test ignored because it won't stop and is used for manual test")
-    public void testConsumingScanEvents() throws Exception {
+    @Disabled("Test ignored because it won't stop and is used for manual test")
+    void testConsumingScanEvents() throws Exception {
 
         inventoryDatabase.createAndInitialize();
 
@@ -127,8 +133,8 @@ public class PostgresSourceExampleTest extends PostgresTestBase {
     }
 
     @Test
-    @Ignore
-    public void testConsumingAllEvents() throws Exception {
+    @Disabled
+    void testConsumingAllEvents() throws Exception {
         final DataType dataType =
                 DataTypes.ROW(
                         DataTypes.FIELD("id", DataTypes.BIGINT()),
@@ -190,7 +196,7 @@ public class PostgresSourceExampleTest extends PostgresTestBase {
         List<String> snapshotActualRecords = formatResult(snapshotRowDataList, dataType);
         assertEqualsInAnyOrder(Arrays.asList(snapshotExpectedRecords), snapshotActualRecords);
 
-        log.info("All snapshot data consumed!");
+        LOG.info("All snapshot data consumed!");
 
         // step-2: make 6 change events in one PostgreSQL transaction
         makeWalEvents(getConnection(), TABLE_ID);
@@ -209,14 +215,14 @@ public class PostgresSourceExampleTest extends PostgresTestBase {
         List<RowData> walRowDataList = new ArrayList<>();
         for (int i = 0; i < walExpectedRecords.length && iterator.hasNext(); i++) {
             RowData rowData = iterator.next();
-            log.info("step 3: consume wal event: {}", rowData);
+            LOG.info("step 3: consume wal event: {}", rowData);
             walRowDataList.add(rowData);
         }
 
         List<String> walActualRecords = formatResult(walRowDataList, dataType);
         assertEqualsInAnyOrder(Arrays.asList(walExpectedRecords), walActualRecords);
 
-        log.info("All streaming events consumed!");
+        LOG.info("All streaming events consumed!");
 
         // stop the worker
         iterator.close();
@@ -279,7 +285,7 @@ public class PostgresSourceExampleTest extends PostgresTestBase {
         SlotState slotState = connection.getReplicationSlotState(SLOT_NAME, PLUGIN_NAME);
 
         while (slotState == null) {
-            log.info("Waiting until the replication slot is ready ...");
+            LOG.info("Waiting until the replication slot is ready ...");
             try {
                 Thread.sleep(2000L);
             } catch (InterruptedException e) {
