@@ -19,6 +19,7 @@ package org.apache.flink.cdc.connectors.postgres.table;
 
 import org.apache.flink.api.common.restartstrategy.RestartStrategies;
 import org.apache.flink.cdc.connectors.postgres.PostgresTestBase;
+import org.apache.flink.cdc.connectors.utils.StaticExternalResourceProxy;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.EnvironmentSettings;
 import org.apache.flink.table.api.TableResult;
@@ -28,32 +29,32 @@ import org.apache.flink.table.utils.LegacyRowResource;
 import org.apache.flink.types.Row;
 import org.apache.flink.types.RowUtils;
 import org.apache.flink.util.CloseableIterator;
-import org.apache.flink.util.ExceptionUtils;
 
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
+import org.testcontainers.containers.PostgreSQLContainer;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
+import org.testcontainers.lifecycle.Startables;
+import org.testcontainers.utility.DockerImageName;
 
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.List;
+import java.util.Random;
 import java.util.concurrent.ExecutionException;
+import java.util.stream.Stream;
 
-import static org.hamcrest.Matchers.containsInAnyOrder;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
 import static org.testcontainers.containers.PostgreSQLContainer.POSTGRESQL_PORT;
 
 /** Integration tests for PostgreSQL Table source. */
-@RunWith(Parameterized.class)
-public class PostgreSQLConnectorITCase extends PostgresTestBase {
+class PostgreSQLConnectorITCase extends PostgresTestBase {
 
     private final StreamExecutionEnvironment env =
             StreamExecutionEnvironment.getExecutionEnvironment();
@@ -61,21 +62,46 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
             StreamTableEnvironment.create(
                     env, EnvironmentSettings.newInstance().inStreamingMode().build());
 
-    @ClassRule public static LegacyRowResource usesLegacyRows = LegacyRowResource.INSTANCE;
+    /** Use postgis plugin to test the GIS type. */
+    protected static final DockerImageName POSTGIS_IMAGE =
+            DockerImageName.parse("postgis/postgis:14-3.5").asCompatibleSubstituteFor("postgres");
 
-    private final boolean parallelismSnapshot;
+    public static final PostgreSQLContainer<?> POSTGIS_CONTAINER =
+            new PostgreSQLContainer<>(POSTGIS_IMAGE)
+                    .withDatabaseName(DEFAULT_DB)
+                    .withUsername("postgres")
+                    .withPassword("postgres")
+                    .withLogConsumer(new Slf4jLogConsumer(LOG))
+                    .withCommand(
+                            "postgres",
+                            "-c",
+                            // default
+                            "fsync=off",
+                            "-c",
+                            "max_replication_slots=20",
+                            "-c",
+                            "wal_level=logical");
 
-    public PostgreSQLConnectorITCase(boolean parallelismSnapshot) {
-        this.parallelismSnapshot = parallelismSnapshot;
+    @RegisterExtension
+    public static StaticExternalResourceProxy<LegacyRowResource> usesLegacyRows =
+            new StaticExternalResourceProxy<>(LegacyRowResource.INSTANCE);
+
+    @BeforeAll
+    static void startContainers() throws Exception {
+        LOG.info("Starting containers...");
+        Startables.deepStart(Stream.of(POSTGRES_CONTAINER, POSTGIS_CONTAINER)).join();
+        LOG.info("Containers are started.");
     }
 
-    @Parameterized.Parameters(name = "parallelismSnapshot: {0}")
-    public static Object[] parameters() {
-        return new Object[][] {new Object[] {true}, new Object[] {false}};
+    @AfterAll
+    static void stopContainers() {
+        LOG.info("Stopping containers...");
+        POSTGIS_CONTAINER.stop();
+        POSTGIS_CONTAINER.stop();
+        LOG.info("Containers are stopped.");
     }
 
-    @Before
-    public void before() {
+    void setup(boolean parallelismSnapshot) {
         TestValuesTableFactory.clearAllData();
         env.setRestartStrategy(RestartStrategies.noRestart());
         if (parallelismSnapshot) {
@@ -86,9 +112,11 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
         }
     }
 
-    @Test
-    public void testConsumingAllEvents()
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testConsumingAllEvents(boolean parallelismSnapshot)
             throws SQLException, ExecutionException, InterruptedException {
+        setup(parallelismSnapshot);
         initializePostgresTable(POSTGRES_CONTAINER, "inventory");
         String sourceDDL =
                 String.format(
@@ -107,6 +135,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + " 'schema-name' = '%s',"
                                 + " 'table-name' = '%s',"
                                 + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'slot.name' = '%s'"
                                 + ")",
                         POSTGRES_CONTAINER.getHost(),
@@ -198,16 +227,15 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                 };
 
         List<String> actual = TestValuesTableFactory.getResultsAsStrings("sink");
-        assertThat(actual, containsInAnyOrder(expected));
+        Assertions.assertThat(actual).containsExactlyInAnyOrder(expected);
 
         result.getJobClient().get().cancel().get();
     }
 
-    @Test
-    public void testStartupFromLatestOffset() throws Exception {
-        if (!parallelismSnapshot) {
-            return;
-        }
+    @ParameterizedTest
+    @ValueSource(booleans = {true})
+    void testStartupFromLatestOffset(boolean parallelismSnapshot) throws Exception {
+        setup(parallelismSnapshot);
         initializePostgresTable(POSTGRES_CONTAINER, "inventory");
         String sourceDDL =
                 String.format(
@@ -227,6 +255,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + " 'schema-name' = '%s',"
                                 + " 'table-name' = '%s',"
                                 + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'slot.name' = '%s',"
                                 + " 'scan.startup.mode' = 'latest-offset'"
                                 + ")",
@@ -272,13 +301,107 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                 new String[] {"110,jacket,new water resistent white wind breaker,0.500"};
 
         List<String> actual = TestValuesTableFactory.getResultsAsStrings("sink");
-        assertThat(actual, containsInAnyOrder(expected));
+        Assertions.assertThat(actual).containsExactlyInAnyOrder(expected);
 
         result.getJobClient().get().cancel().get();
     }
 
-    @Test
-    public void testExceptionForReplicaIdentity() throws Exception {
+    @ParameterizedTest
+    @ValueSource(booleans = {true})
+    public void testStartupFromCommittedOffset(boolean parallelismSnapshot) throws Exception {
+        setup(parallelismSnapshot);
+        initializePostgresTable(POSTGRES_CONTAINER, "inventory");
+        try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
+                Statement statement = connection.createStatement()) {
+            statement.execute(
+                    "INSERT INTO inventory.products VALUES (default,'first','first description',0.1);");
+            statement.execute(
+                    "INSERT INTO inventory.products VALUES (default,'second','second description',0.2);");
+        }
+
+        // newly create slot's confirmed lsn is latest. We will test whether committed mode starts
+        // from here.
+        String slotName = getSlotName();
+        String publicName = "dbz_publication_" + new Random().nextInt(1000);
+        try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
+                Statement statement = connection.createStatement()) {
+            // TODO: Remove it after adding publication to an existing replication slot.
+            statement.execute(
+                    String.format(
+                            "CREATE PUBLICATION %s FOR TABLE inventory.products", publicName));
+            statement.execute(
+                    String.format(
+                            "select pg_create_logical_replication_slot('%s','pgoutput');",
+                            slotName));
+        }
+
+        try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
+                Statement statement = connection.createStatement()) {
+            statement.execute(
+                    "INSERT INTO inventory.products VALUES (default,'thirth','thirth description',0.1);");
+            statement.execute(
+                    "INSERT INTO inventory.products VALUES (default,'forth','forth description',0.2);");
+        }
+
+        String sourceDDL =
+                String.format(
+                        "CREATE TABLE debezium_source ("
+                                + " id INT NOT NULL,"
+                                + " name STRING,"
+                                + " description STRING,"
+                                + " weight DECIMAL(10,3),"
+                                + " PRIMARY KEY (id) NOT ENFORCED"
+                                + ") WITH ("
+                                + " 'connector' = 'postgres-cdc',"
+                                + " 'hostname' = '%s',"
+                                + " 'port' = '%s',"
+                                + " 'username' = '%s',"
+                                + " 'password' = '%s',"
+                                + " 'database-name' = '%s',"
+                                + " 'schema-name' = '%s',"
+                                + " 'table-name' = '%s',"
+                                + " 'scan.incremental.snapshot.enabled' = 'true',"
+                                + " 'decoding.plugin.name' = 'pgoutput',"
+                                + " 'slot.name' = '%s',"
+                                + " 'debezium.publication.name'  = '%s',"
+                                + " 'scan.lsn-commit.checkpoints-num-delay' = '0',"
+                                + " 'scan.startup.mode' = 'committed-offset'"
+                                + ")",
+                        POSTGRES_CONTAINER.getHost(),
+                        POSTGRES_CONTAINER.getMappedPort(POSTGRESQL_PORT),
+                        POSTGRES_CONTAINER.getUsername(),
+                        POSTGRES_CONTAINER.getPassword(),
+                        POSTGRES_CONTAINER.getDatabaseName(),
+                        "inventory",
+                        "products",
+                        slotName,
+                        publicName);
+        String sinkDDL =
+                "CREATE TABLE sink "
+                        + " WITH ("
+                        + " 'connector' = 'values',"
+                        + " 'sink-insert-only' = 'false'"
+                        + ") LIKE debezium_source (EXCLUDING OPTIONS)";
+        tEnv.executeSql(sourceDDL);
+        tEnv.executeSql(sinkDDL);
+
+        TableResult result = tEnv.executeSql("INSERT INTO sink SELECT * FROM debezium_source");
+        waitForSinkSize("sink", 2);
+
+        String[] expected =
+                new String[] {
+                    "112,thirth,thirth description,0.100", "113,forth,forth description,0.200"
+                };
+
+        List<String> actual = TestValuesTableFactory.getResultsAsStrings("sink");
+        Assertions.assertThat(actual).containsExactlyInAnyOrder(expected);
+        result.getJobClient().get().cancel().get();
+    }
+
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testExceptionForReplicaIdentity(boolean parallelismSnapshot) throws Exception {
+        setup(parallelismSnapshot);
         initializePostgresTable(POSTGRES_CONTAINER, "replica_identity");
         String sourceDDL =
                 String.format(
@@ -297,6 +420,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + " 'schema-name' = '%s',"
                                 + " 'table-name' = '%s',"
                                 + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'slot.name' = '%s'"
                                 + ")",
                         POSTGRES_CONTAINER.getHost(),
@@ -347,21 +471,17 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
             statement.execute("DELETE FROM inventory.products WHERE id=111;");
         }
 
-        try {
-            result.await();
-        } catch (Exception e) {
-            assertTrue(
-                    ExceptionUtils.findThrowableWithMessage(
-                                    e,
-                                    "The \"before\" field of UPDATE/DELETE message is null, "
-                                            + "please check the Postgres table has been set REPLICA IDENTITY to FULL level.")
-                            .isPresent());
-        }
+        Assertions.assertThatThrownBy(result::await)
+                .hasStackTraceContaining(
+                        "The \"before\" field of UPDATE/DELETE message is null, "
+                                + "please check the Postgres table has been set REPLICA IDENTITY to FULL level.");
     }
 
-    @Test
-    public void testAllTypes() throws Throwable {
-        initializePostgresTable(POSTGRES_CONTAINER, "column_type_test");
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testAllTypes(boolean parallelismSnapshot) throws Throwable {
+        setup(parallelismSnapshot);
+        initializePostgresTable(POSTGIS_CONTAINER, "column_type_test");
 
         String sourceDDL =
                 String.format(
@@ -397,13 +517,14 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + " 'schema-name' = '%s',"
                                 + " 'table-name' = '%s',"
                                 + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'slot.name' = '%s'"
                                 + ")",
-                        POSTGRES_CONTAINER.getHost(),
-                        POSTGRES_CONTAINER.getMappedPort(POSTGRESQL_PORT),
-                        POSTGRES_CONTAINER.getUsername(),
-                        POSTGRES_CONTAINER.getPassword(),
-                        POSTGRES_CONTAINER.getDatabaseName(),
+                        POSTGIS_CONTAINER.getHost(),
+                        POSTGIS_CONTAINER.getMappedPort(POSTGRESQL_PORT),
+                        POSTGIS_CONTAINER.getUsername(),
+                        POSTGIS_CONTAINER.getPassword(),
+                        POSTGIS_CONTAINER.getDatabaseName(),
                         "inventory",
                         "full_types",
                         parallelismSnapshot,
@@ -447,7 +568,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
         Thread.sleep(5000);
 
         // generate WAL
-        try (Connection connection = getJdbcConnection(POSTGRES_CONTAINER);
+        try (Connection connection = getJdbcConnection(POSTGIS_CONTAINER);
                 Statement statement = connection.createStatement()) {
             statement.execute("UPDATE inventory.full_types SET small_c=0 WHERE id=1;");
         }
@@ -460,13 +581,15 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                         "-D(1,[50],32767,65535,2147483647,5.5,6.6,123.12345,404.4,true,Hello World,a,abc,abcd..xyz,2020-07-17T18:00:22.123,2020-07-17T18:00:22.123456,2020-07-17,18:00:22,500,{\"hexewkb\":\"0105000020e610000001000000010200000002000000a779c7293a2465400b462575025a46c0c66d3480b7fc6440c3d32b65195246c0\",\"srid\":4326},{\"hexewkb\":\"0101000020730c00001c7c613255de6540787aa52c435c42c0\",\"srid\":3187})",
                         "+I(1,[50],0,65535,2147483647,5.5,6.6,123.12345,404.4,true,Hello World,a,abc,abcd..xyz,2020-07-17T18:00:22.123,2020-07-17T18:00:22.123456,2020-07-17,18:00:22,500,{\"hexewkb\":\"0105000020e610000001000000010200000002000000a779c7293a2465400b462575025a46c0c66d3480b7fc6440c3d32b65195246c0\",\"srid\":4326},{\"hexewkb\":\"0101000020730c00001c7c613255de6540787aa52c435c42c0\",\"srid\":3187})");
         List<String> actual = TestValuesTableFactory.getRawResultsAsStrings("sink");
-        assertEquals(expected, actual);
+        Assertions.assertThat(actual).isEqualTo(expected);
 
         result.getJobClient().get().cancel().get();
     }
 
-    @Test
-    public void testMetadataColumns() throws Throwable {
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testMetadataColumns(boolean parallelismSnapshot) throws Throwable {
+        setup(parallelismSnapshot);
         initializePostgresTable(POSTGRES_CONTAINER, "inventory");
         String sourceDDL =
                 String.format(
@@ -490,6 +613,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + " 'schema-name' = '%s',"
                                 + " 'table-name' = '%s',"
                                 + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'slot.name' = '%s'"
                                 + ")",
                         POSTGRES_CONTAINER.getHost(),
@@ -600,14 +724,14 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + databaseName
                                 + ",inventory,products,-D,111,scooter,Big 2-wheel scooter ,5.170)");
         List<String> actual = TestValuesTableFactory.getRawResultsAsStrings("sink");
-        Collections.sort(actual);
-        Collections.sort(expected);
-        assertEquals(expected, actual);
+        Assertions.assertThat(actual).containsExactlyInAnyOrderElementsOf(expected);
         result.getJobClient().get().cancel().get();
     }
 
-    @Test
-    public void testUpsertMode() throws Exception {
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testUpsertMode(boolean parallelismSnapshot) throws Exception {
+        setup(parallelismSnapshot);
         initializePostgresTable(POSTGRES_CONTAINER, "replica_identity");
         String sourceDDL =
                 String.format(
@@ -628,6 +752,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + " 'table-name' = '%s',"
                                 + " 'slot.name' = '%s',"
                                 + " 'scan.incremental.snapshot.enabled' = '%s',"
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'changelog-mode' = '%s'"
                                 + ")",
                         POSTGRES_CONTAINER.getHost(),
@@ -719,13 +844,15 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                 };
 
         List<String> actual = TestValuesTableFactory.getResultsAsStrings("sink");
-        assertThat(actual, containsInAnyOrder(expected));
+        Assertions.assertThat(actual).containsExactlyInAnyOrder(expected);
 
         result.getJobClient().get().cancel().get();
     }
 
-    @Test
-    public void testUniqueIndexIncludingFunction() throws Exception {
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    void testUniqueIndexIncludingFunction(boolean parallelismSnapshot) throws Exception {
+        setup(parallelismSnapshot);
         // Clear the influence of usesLegacyRows which set USE_LEGACY_TO_STRING = true.
         // In this test, print +I,-U, +U to see more clearly.
         RowUtils.USE_LEGACY_TO_STRING = false;
@@ -753,6 +880,7 @@ public class PostgreSQLConnectorITCase extends PostgresTestBase {
                                 + (parallelismSnapshot
                                         ? " 'scan.startup.mode' = 'latest-offset',"
                                         : "")
+                                + " 'decoding.plugin.name' = 'pgoutput', "
                                 + " 'slot.name' = '%s'"
                                 + ")",
                         POSTGRES_CONTAINER.getHost(),
