@@ -38,9 +38,9 @@ import org.apache.flink.table.data.RowData;
 import org.apache.flink.table.factories.Factory;
 import org.apache.flink.table.factories.FactoryUtil;
 import org.apache.flink.table.runtime.connector.source.ScanRuntimeProviderContext;
-import org.apache.flink.util.ExceptionUtils;
 
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import java.time.Duration;
 import java.util.ArrayList;
@@ -57,6 +57,7 @@ import static org.apache.flink.cdc.connectors.base.options.SourceOptions.CHUNK_M
 import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED;
 import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SCAN_INCREMENTAL_SNAPSHOT_BACKFILL_SKIP;
 import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SCAN_INCREMENTAL_SNAPSHOT_CHUNK_SIZE;
+import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED;
 import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SCAN_NEWLY_ADDED_TABLE_ENABLED;
 import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SCAN_SNAPSHOT_FETCH_SIZE;
 import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SPLIT_KEY_EVEN_DISTRIBUTION_FACTOR_LOWER_BOUND;
@@ -64,12 +65,9 @@ import static org.apache.flink.cdc.connectors.base.options.SourceOptions.SPLIT_K
 import static org.apache.flink.cdc.connectors.postgres.source.config.PostgresSourceOptions.HEARTBEAT_INTERVAL;
 import static org.apache.flink.cdc.connectors.postgres.source.config.PostgresSourceOptions.SCAN_LSN_COMMIT_CHECKPOINTS_DELAY;
 import static org.apache.flink.cdc.connectors.utils.AssertUtils.assertProducedTypeOfSourceFunction;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
 /** Test for {@link PostgreSQLTableSource} created by {@link PostgreSQLTableFactory}. */
-public class PostgreSQLTableFactoryTest {
+class PostgreSQLTableFactoryTest {
 
     private static final ResolvedSchema SCHEMA =
             new ResolvedSchema(
@@ -120,7 +118,7 @@ public class PostgreSQLTableFactoryTest {
             SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED.defaultValue();
 
     @Test
-    public void testCommonProperties() {
+    void testCommonProperties() {
         Map<String, String> properties = getAllOptions();
 
         // validation for source
@@ -154,12 +152,13 @@ public class PostgreSQLTableFactoryTest {
                         SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED_DEFAULT,
                         SCAN_INCREMENTAL_SNAPSHOT_BACKFILL_SKIP.defaultValue(),
                         SCAN_NEWLY_ADDED_TABLE_ENABLED.defaultValue(),
-                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue());
-        assertEquals(expectedSource, actualSource);
+                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue(),
+                        SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED.defaultValue());
+        Assertions.assertThat(actualSource).isEqualTo(expectedSource);
     }
 
     @Test
-    public void testOptionalProperties() {
+    void testOptionalProperties() {
         Map<String, String> options = getAllOptions();
         options.put("port", "5444");
         options.put("decoding.plugin.name", "wal2json");
@@ -200,12 +199,13 @@ public class PostgreSQLTableFactoryTest {
                         SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED_DEFAULT,
                         true,
                         true,
-                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue());
-        assertEquals(expectedSource, actualSource);
+                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue(),
+                        SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED.defaultValue());
+        Assertions.assertThat(actualSource).isEqualTo(expectedSource);
     }
 
     @Test
-    public void testMetadataColumns() {
+    void testMetadataColumns() {
         Map<String, String> properties = getAllOptions();
 
         // validation for source
@@ -244,12 +244,13 @@ public class PostgreSQLTableFactoryTest {
                         SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED_DEFAULT,
                         SCAN_INCREMENTAL_SNAPSHOT_BACKFILL_SKIP.defaultValue(),
                         SCAN_NEWLY_ADDED_TABLE_ENABLED.defaultValue(),
-                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue());
+                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue(),
+                        SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED.defaultValue());
         expectedSource.producedDataType = SCHEMA_WITH_METADATA.toSourceRowDataType();
         expectedSource.metadataKeys =
                 Arrays.asList("row_kind", "op_ts", "database_name", "schema_name", "table_name");
 
-        assertEquals(expectedSource, actualSource);
+        Assertions.assertThat(actualSource).isEqualTo(expectedSource);
 
         ScanTableSource.ScanRuntimeProvider provider =
                 postgreSQLTableSource.getScanRuntimeProvider(ScanRuntimeProviderContext.INSTANCE);
@@ -260,7 +261,7 @@ public class PostgreSQLTableFactoryTest {
     }
 
     @Test
-    public void testEnableParallelReadSource() {
+    void testEnableParallelReadSource() {
         Map<String, String> properties = getAllOptions();
         properties.put("scan.incremental.snapshot.enabled", "true");
         properties.put("scan.incremental.snapshot.chunk.size", "8000");
@@ -298,12 +299,13 @@ public class PostgreSQLTableFactoryTest {
                         SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED_DEFAULT,
                         SCAN_INCREMENTAL_SNAPSHOT_BACKFILL_SKIP.defaultValue(),
                         SCAN_NEWLY_ADDED_TABLE_ENABLED.defaultValue(),
-                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue());
-        assertEquals(expectedSource, actualSource);
+                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue(),
+                        SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED.defaultValue());
+        Assertions.assertThat(actualSource).isEqualTo(expectedSource);
     }
 
     @Test
-    public void testStartupFromLatestOffset() {
+    void testStartupFromLatestOffset() {
         Map<String, String> properties = getAllOptions();
         properties.put("scan.incremental.snapshot.enabled", "true");
         properties.put("scan.incremental.snapshot.chunk.size", "8000");
@@ -342,25 +344,21 @@ public class PostgreSQLTableFactoryTest {
                         SCAN_INCREMENTAL_CLOSE_IDLE_READER_ENABLED_DEFAULT,
                         SCAN_INCREMENTAL_SNAPSHOT_BACKFILL_SKIP.defaultValue(),
                         SCAN_NEWLY_ADDED_TABLE_ENABLED.defaultValue(),
-                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue());
-        assertEquals(expectedSource, actualSource);
+                        SCAN_LSN_COMMIT_CHECKPOINTS_DELAY.defaultValue(),
+                        SCAN_INCREMENTAL_SNAPSHOT_UNBOUNDED_CHUNK_FIRST_ENABLED.defaultValue());
+        Assertions.assertThat(actualSource).isEqualTo(expectedSource);
     }
 
     @Test
-    public void testValidation() {
+    void testValidation() {
         // validate illegal port
-        try {
-            Map<String, String> properties = getAllOptions();
-            properties.put("port", "123b");
-
-            createTableSource(properties);
-            fail("exception expected");
-        } catch (Throwable t) {
-            assertTrue(
-                    ExceptionUtils.findThrowableWithMessage(
-                                    t, "Could not parse value '123b' for key 'port'.")
-                            .isPresent());
-        }
+        Assertions.assertThatThrownBy(
+                        () -> {
+                            Map<String, String> properties = getAllOptions();
+                            properties.put("port", "123b");
+                            createTableSource(properties);
+                        })
+                .hasStackTraceContaining("Could not parse value '123b' for key 'port'.");
 
         // validate missing required
         Factory factory = new PostgreSQLTableFactory();
@@ -368,46 +366,32 @@ public class PostgreSQLTableFactoryTest {
             Map<String, String> properties = getAllOptions();
             properties.remove(requiredOption.key());
 
-            try {
-                createTableSource(SCHEMA, properties);
-                fail("exception expected");
-            } catch (Throwable t) {
-                assertTrue(
-                        ExceptionUtils.findThrowableWithMessage(
-                                        t,
-                                        "Missing required options are:\n\n" + requiredOption.key())
-                                .isPresent());
-            }
+            Assertions.assertThatThrownBy(() -> createTableSource(SCHEMA, properties))
+                    .hasStackTraceContaining(
+                            "Missing required options are:\n\n" + requiredOption.key());
         }
 
         // validate unsupported option
-        try {
-            Map<String, String> properties = getAllOptions();
-            properties.put("unknown", "abc");
-
-            createTableSource(properties);
-            fail("exception expected");
-        } catch (Throwable t) {
-            assertTrue(
-                    ExceptionUtils.findThrowableWithMessage(t, "Unsupported options:\n\nunknown")
-                            .isPresent());
-        }
+        Assertions.assertThatThrownBy(
+                        () -> {
+                            Map<String, String> properties = getAllOptions();
+                            properties.put("unknown", "abc");
+                            createTableSource(properties);
+                        })
+                .hasStackTraceContaining("Unsupported options:\n\nunknown");
     }
 
     @Test
-    public void testUpsertModeWithoutPrimaryKeyError() {
-        try {
-            Map<String, String> properties = getAllOptions();
-            properties.put("changelog-mode", "upsert");
+    void testUpsertModeWithoutPrimaryKeyError() {
+        Assertions.assertThatThrownBy(
+                        () -> {
+                            Map<String, String> properties = getAllOptions();
+                            properties.put("changelog-mode", "upsert");
 
-            createTableSource(SCHEMA_WITHOUT_PRIMARY_KEY, properties);
-            fail("exception expected");
-        } catch (Throwable t) {
-            assertTrue(
-                    ExceptionUtils.findThrowableWithMessage(
-                                    t, "Primary key must be present when upsert mode is selected.")
-                            .isPresent());
-        }
+                            createTableSource(SCHEMA_WITHOUT_PRIMARY_KEY, properties);
+                        })
+                .hasStackTraceContaining(
+                        "Primary key must be present when upsert mode is selected.");
     }
 
     private Map<String, String> getAllOptions() {
