@@ -18,6 +18,7 @@
 package org.apache.flink.cdc.connectors.sqlserver.source.utils;
 
 import org.apache.flink.cdc.connectors.base.source.meta.offset.Offset;
+import org.apache.flink.cdc.connectors.base.utils.ObjectUtils;
 import org.apache.flink.cdc.connectors.sqlserver.source.offset.LsnOffset;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.types.logical.RowType;
@@ -40,17 +41,19 @@ import org.apache.kafka.connect.source.SourceRecord;
 
 import javax.annotation.Nullable;
 
+import java.nio.ByteBuffer;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.UUID;
 import java.util.stream.Collectors;
 
-import static org.apache.flink.cdc.connectors.base.utils.SourceRecordUtils.rowToArray;
 import static org.apache.flink.table.api.DataTypes.FIELD;
 import static org.apache.flink.table.api.DataTypes.ROW;
 
@@ -59,26 +62,6 @@ public class SqlServerUtils {
 
     public SqlServerUtils() {}
 
-    public static Object[] queryMinMax(JdbcConnection jdbc, TableId tableId, String columnName)
-            throws SQLException {
-        final String minMaxQuery =
-                String.format(
-                        "SELECT MIN(%s), MAX(%s) FROM %s",
-                        quote(columnName), quote(columnName), quote(tableId));
-        return jdbc.queryAndMap(
-                minMaxQuery,
-                rs -> {
-                    if (!rs.next()) {
-                        // this should never happen
-                        throw new SQLException(
-                                String.format(
-                                        "No result returned after running query [%s]",
-                                        minMaxQuery));
-                    }
-                    return rowToArray(rs, 2);
-                });
-    }
-
     public static long queryApproximateRowCnt(JdbcConnection jdbc, TableId tableId)
             throws SQLException {
         // The statement used to get approximate row count which is less
@@ -103,27 +86,6 @@ public class SqlServerUtils {
                 });
     }
 
-    public static Object queryMin(
-            JdbcConnection jdbc, TableId tableId, String columnName, Object excludedLowerBound)
-            throws SQLException {
-        final String minQuery =
-                String.format(
-                        "SELECT MIN(%s) FROM %s WHERE %s > ?",
-                        quote(columnName), quote(tableId), quote(columnName));
-        return jdbc.prepareQueryAndMap(
-                minQuery,
-                ps -> ps.setObject(1, excludedLowerBound),
-                rs -> {
-                    if (!rs.next()) {
-                        // this should never happen
-                        throw new SQLException(
-                                String.format(
-                                        "No result returned after running query [%s]", minQuery));
-                    }
-                    return rs.getObject(1);
-                });
-    }
-
     /**
      * Returns the next LSN to be read from the database. This is the LSN of the last record that
      * was read from the database.
@@ -339,8 +301,7 @@ public class SqlServerUtils {
             return buildSelectWithRowLimits(
                     tableId, limitSize, "*", Optional.ofNullable(condition), Optional.empty());
         } else {
-            final String orderBy =
-                    pkRowType.getFieldNames().stream().collect(Collectors.joining(", "));
+            final String orderBy = String.join(", ", pkRowType.getFieldNames());
             return buildSelectWithBoundaryRowLimits(
                     tableId,
                     limitSize,
@@ -364,7 +325,7 @@ public class SqlServerUtils {
         StringBuilder sql = new StringBuilder();
         for (Iterator<String> fieldNamesIt = pkRowType.getFieldNames().iterator();
                 fieldNamesIt.hasNext(); ) {
-            sql.append("MAX(" + fieldNamesIt.next() + ")");
+            sql.append("MAX(").append(fieldNamesIt.next()).append(")");
             if (fieldNamesIt.hasNext()) {
                 sql.append(" , ");
             }
@@ -384,12 +345,8 @@ public class SqlServerUtils {
         }
         sql.append(projection).append(" FROM ");
         sql.append(quoteSchemaAndTable(tableId));
-        if (condition.isPresent()) {
-            sql.append(" WHERE ").append(condition.get());
-        }
-        if (orderBy.isPresent()) {
-            sql.append(" ORDER BY ").append(orderBy.get());
-        }
+        condition.ifPresent(s -> sql.append(" WHERE ").append(s));
+        orderBy.ifPresent(s -> sql.append(" ORDER BY ").append(s));
         return sql.toString();
     }
 
@@ -438,11 +395,54 @@ public class SqlServerUtils {
         sql.append(projection);
         sql.append(" FROM ");
         sql.append(quoteSchemaAndTable(tableId));
-        if (condition.isPresent()) {
-            sql.append(" WHERE ").append(condition.get());
-        }
+        condition.ifPresent(s -> sql.append(" WHERE ").append(s));
         sql.append(" ORDER BY ").append(orderBy);
         sql.append(") T");
         return sql.toString();
     }
+
+    public static int compare(Object obj1, Object obj2, Column splitColumn) {
+        if (splitColumn.typeName().equals(SqlServerTypeUtils.UNIQUEIDENTIFIRER)) {
+            return new SQLServerUUIDComparator()
+                    .compare(UUID.fromString(obj1.toString()), UUID.fromString(obj2.toString()));
+        }
+        return ObjectUtils.compare(obj1, obj2);
+    }
+
+    /**
+     * Comparator for SQL Server UUIDs. SQL Server compares UUIDs in a different order than Java.
+     * Reference code: <a
+     * href="https://github.com/dotnet/runtime/blob/5535e31a712343a63f5d7d796cd874e563e5ac14/src/libraries/System.Data.Common/src/System/Data/SQLTypes/SQLGuid.cs#L113">SQLGuid.cs::CompareTo</a>
+     * Reference doc: <a
+     * href="https://learn.microsoft.com/uk-ua/sql/connect/ado-net/sql/compare-guid-uniqueidentifier-values?view=sql-server-ver16">Comparing
+     * GUID and uniqueidentifier values</a>
+     */
+    static class SQLServerUUIDComparator implements Comparator<UUID> {
+
+        private static final int SIZE_OF_GUID = 16;
+        private static final byte[] GUID_ORDER = {
+            10, 11, 12, 13, 14, 15, 8, 9, 6, 7, 4, 5, 0, 1, 2, 3
+        };
+
+        public int compare(UUID uuid1, UUID uuid2) {
+            byte[] bytes1 = uuidToBytes(uuid1);
+            byte[] bytes2 = uuidToBytes(uuid2);
+
+            for (int i = 0; i < SIZE_OF_GUID; i++) {
+                byte b1 = bytes1[GUID_ORDER[i]];
+                byte b2 = bytes2[GUID_ORDER[i]];
+                if (b1 != b2) {
+                    return (b1 & 0xFF) - (b2 & 0xFF); // Unsigned byte comparison
+                }
+            }
+            return 0;
+        }
+
+        private byte[] uuidToBytes(UUID uuid) {
+            ByteBuffer bb = ByteBuffer.wrap(new byte[16]);
+            bb.putLong(uuid.getMostSignificantBits());
+            bb.putLong(uuid.getLeastSignificantBits());
+            return bb.array();
+        }
+    }
 }
