@@ -17,13 +17,16 @@
 
 package org.apache.flink.cdc.connectors.sqlserver;
 
+import org.apache.flink.cdc.connectors.sqlserver.source.SqlServerSourceTestBase;
+import org.apache.flink.cdc.connectors.sqlserver.source.config.SqlServerSourceConfigFactory;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
 import org.apache.flink.test.util.AbstractTestBase;
 
+import org.assertj.core.api.Assertions;
 import org.awaitility.Awaitility;
 import org.awaitility.core.ConditionTimeoutException;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testcontainers.containers.MSSQLServerContainer;
@@ -46,7 +49,7 @@ import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-import static org.junit.Assert.assertNotNull;
+import static org.testcontainers.containers.MSSQLServerContainer.MS_SQL_SERVER_PORT;
 
 /** Utility class for sqlserver tests. */
 public class SqlServerTestBase extends AbstractTestBase {
@@ -59,22 +62,22 @@ public class SqlServerTestBase extends AbstractTestBase {
             "IF EXISTS(select 1 from sys.databases where name='#' AND is_cdc_enabled=1)\n"
                     + "EXEC sys.sp_cdc_disable_db";
 
-    public static final MSSQLServerContainer MSSQL_SERVER_CONTAINER =
+    public static final MSSQLServerContainer<?> MSSQL_SERVER_CONTAINER =
             new MSSQLServerContainer<>("mcr.microsoft.com/mssql/server:2019-latest")
                     .withPassword("Password!")
                     .withEnv("MSSQL_AGENT_ENABLED", "true")
                     .withEnv("MSSQL_PID", "Standard")
                     .withLogConsumer(new Slf4jLogConsumer(LOG));
 
-    @BeforeClass
-    public static void startContainers() {
+    @BeforeAll
+    static void startContainers() throws Exception {
         LOG.info("Starting containers...");
         Startables.deepStart(Stream.of(MSSQL_SERVER_CONTAINER)).join();
         LOG.info("Containers are started.");
     }
 
-    @AfterClass
-    public static void stopContainers() {
+    @AfterAll
+    static void stopContainers() {
         LOG.info("Stopping containers...");
         if (MSSQL_SERVER_CONTAINER != null) {
             MSSQL_SERVER_CONTAINER.stop();
@@ -173,7 +176,7 @@ public class SqlServerTestBase extends AbstractTestBase {
     protected void initializeSqlServerTable(String sqlFile) {
         final String ddlFile = String.format("ddl/%s.sql", sqlFile);
         final URL ddlTestFile = SqlServerTestBase.class.getClassLoader().getResource(ddlFile);
-        assertNotNull("Cannot locate " + ddlFile, ddlTestFile);
+        Assertions.assertThat(ddlTestFile).withFailMessage("Cannot locate " + ddlFile).isNotNull();
         try (Connection connection = getJdbcConnection();
                 Statement statement = connection.createStatement()) {
             dropTestDatabase(connection, sqlFile);
@@ -222,4 +225,19 @@ public class SqlServerTestBase extends AbstractTestBase {
             }
         }
     }
+
+    public static SqlServerSourceConfigFactory getConfigFactory(
+            String databaseName, String[] captureTables, int splitSize) {
+        return (SqlServerSourceConfigFactory)
+                new SqlServerSourceConfigFactory()
+                        .hostname(SqlServerSourceTestBase.MSSQL_SERVER_CONTAINER.getHost())
+                        .port(
+                                SqlServerSourceTestBase.MSSQL_SERVER_CONTAINER.getMappedPort(
+                                        MS_SQL_SERVER_PORT))
+                        .username(SqlServerSourceTestBase.MSSQL_SERVER_CONTAINER.getUsername())
+                        .password(SqlServerSourceTestBase.MSSQL_SERVER_CONTAINER.getPassword())
+                        .databaseList(databaseName)
+                        .tableList(captureTables)
+                        .splitSize(splitSize);
+    }
 }
