@@ -24,24 +24,21 @@ import org.apache.flink.table.api.TableResult;
 import org.apache.flink.table.api.bridge.java.StreamTableEnvironment;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
 
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 
 import java.time.ZoneId;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.TimeZone;
 import java.util.concurrent.ExecutionException;
 
-import static org.junit.Assert.assertEquals;
 import static org.testcontainers.containers.MSSQLServerContainer.MS_SQL_SERVER_PORT;
 
 /** Integration tests for SqlServer Table source. */
-@RunWith(Parameterized.class)
-public class SqlServerTimezoneITCase extends SqlServerTestBase {
+class SqlServerTimezoneITCase extends SqlServerTestBase {
 
     private final StreamExecutionEnvironment env =
             StreamExecutionEnvironment.getExecutionEnvironment();
@@ -49,52 +46,49 @@ public class SqlServerTimezoneITCase extends SqlServerTestBase {
             StreamTableEnvironment.create(
                     env, EnvironmentSettings.newInstance().inStreamingMode().build());
 
-    @Parameterized.Parameter public String timeZone;
-
-    @Parameterized.Parameters(name = "timeZone: {0}")
-    public static List<String> parameters() {
-        return Arrays.asList("Asia/Shanghai", "Europe/Berlin", "UTC");
-    }
-
-    @Before
+    @BeforeEach
     public void before() {
         TestValuesTableFactory.clearAllData();
         env.setParallelism(1);
     }
 
-    @Test
-    public void testTimeTypeWithDifferentLocalTimeZones() throws Exception {
+    @ParameterizedTest
+    @ValueSource(strings = {"Asia/Shanghai", "Europe/Berlin", "UTC"})
+    void testTimeTypeWithDifferentLocalTimeZones(String timeZone) throws Exception {
         List<String> actual = getTimestampResult(timeZone, "UTC", "UTC", false);
         // timestamp_ltz is not determined by timezones, different local timezone with same value.
         List<String> expected =
                 Collections.singletonList(
                         "+I[0, 2018-07-13, 10:23:45.680, 10:23:45.678, 2018-07-13T11:23:45.340, 2018-07-13T01:23:45.456Z, 2018-07-13T13:23:45.780, 2018-07-13T14:24]");
 
-        assertEquals(expected, actual);
+        Assertions.assertThat(actual).isEqualTo(expected);
     }
 
-    @Test
-    public void testTimeTypeWithDifferentServerTimeZones() throws Exception {
+    @ParameterizedTest
+    @ValueSource(strings = {"Asia/Shanghai", "Europe/Berlin", "UTC"})
+    void testTimeTypeWithDifferentServerTimeZones(String timeZone) throws Exception {
         List<String> actual = getTimestampResult("UTC", timeZone, "UTC", false);
         // timestamp_ltz is not determined by timezones, different server timeZone with same value.
         List<String> expected =
                 Collections.singletonList(
                         "+I[0, 2018-07-13, 10:23:45.680, 10:23:45.678, 2018-07-13T11:23:45.340, 2018-07-13T01:23:45.456Z, 2018-07-13T13:23:45.780, 2018-07-13T14:24]");
-        assertEquals(expected, actual);
+        Assertions.assertThat(actual).isEqualTo(expected);
     }
 
-    @Test
-    public void testTimeTypeWithDifferentJVMTimeZones() throws Exception {
+    @ParameterizedTest
+    @ValueSource(strings = {"Asia/Shanghai", "Europe/Berlin", "UTC"})
+    void testTimeTypeWithDifferentJVMTimeZones(String timeZone) throws Exception {
         List<String> actual = getTimestampResult("UTC", "UTC", timeZone, false);
         // timestamp_ltz is not determined by timezones, different jvm timezone with same value.
         List<String> expected =
                 Collections.singletonList(
                         "+I[0, 2018-07-13, 10:23:45.680, 10:23:45.678, 2018-07-13T11:23:45.340, 2018-07-13T01:23:45.456Z, 2018-07-13T13:23:45.780, 2018-07-13T14:24]");
-        assertEquals(expected, actual);
+        Assertions.assertThat(actual).isEqualTo(expected);
     }
 
-    @Test
-    public void testTimeTypeLtz2ntz() throws Exception {
+    @ParameterizedTest
+    @ValueSource(strings = {"Asia/Shanghai", "Europe/Berlin", "UTC"})
+    void testTimeTypeLtz2ntz(String timeZone) throws Exception {
         List<String> actual = getTimestampResult(timeZone, "UTC", "UTC", true);
 
         // A timestamp value from a same timestamp_ltz value is determined by flink timezone,
@@ -117,7 +111,7 @@ public class SqlServerTimezoneITCase extends SqlServerTestBase {
                                 "+I[0, 2018-07-13, 10:23:45.680, 10:23:45.678, 2018-07-13T11:23:45.340, 2018-07-13T01:23:45.456, 2018-07-13T13:23:45.780, 2018-07-13T14:24]");
                 break;
         }
-        assertEquals(expected, actual);
+        Assertions.assertThat(actual).isEqualTo(expected);
     }
 
     public List<String> getTimestampResult(
