@@ -17,9 +17,12 @@
 
 package org.apache.flink.cdc.pipeline.tests.utils;
 
+import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.api.common.time.Deadline;
 import org.apache.flink.cdc.common.test.utils.TestUtils;
+import org.apache.flink.cdc.connectors.mysql.testutils.MySqlContainer;
+import org.apache.flink.cdc.connectors.mysql.testutils.MySqlVersion;
 import org.apache.flink.client.deployment.StandaloneClusterId;
 import org.apache.flink.client.program.rest.RestClusterClient;
 import org.apache.flink.configuration.Configuration;
@@ -28,17 +31,11 @@ import org.apache.flink.runtime.client.JobStatusMessage;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.util.TestLogger;
 
-import com.fasterxml.jackson.core.Version;
 import com.github.dockerjava.api.DockerClient;
 import com.github.dockerjava.api.command.ExecCreateCmdResponse;
 import com.github.dockerjava.api.model.Volume;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Rule;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testcontainers.DockerClientFactory;
@@ -48,7 +45,11 @@ import org.testcontainers.containers.GenericContainer;
 import org.testcontainers.containers.Network;
 import org.testcontainers.containers.output.FrameConsumerResultCallback;
 import org.testcontainers.containers.output.OutputFrame;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.containers.output.ToStringConsumer;
+import org.testcontainers.images.builder.Transferable;
+import org.testcontainers.junit.jupiter.Container;
+import org.testcontainers.junit.jupiter.Testcontainers;
 import org.testcontainers.lifecycle.Startables;
 import org.testcontainers.utility.MountableFile;
 
@@ -60,24 +61,25 @@ import java.net.URL;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.time.Duration;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.TimeUnit;
-import java.util.stream.Collectors;
+import java.util.concurrent.TimeoutException;
+import java.util.function.Function;
 import java.util.stream.Stream;
 
 import static org.apache.flink.util.Preconditions.checkState;
 
 /** Test environment running pipeline job on Flink containers. */
-@RunWith(Parameterized.class)
+@Testcontainers
 public abstract class PipelineTestEnvironment extends TestLogger {
+
     private static final Logger LOG = LoggerFactory.getLogger(PipelineTestEnvironment.class);
 
-    @Parameterized.Parameter public String flinkVersion;
-
-    public Integer parallelism = getParallelism();
+    protected Integer parallelism = getParallelism();
 
     private int getParallelism() {
         try {
@@ -90,13 +92,37 @@ public abstract class PipelineTestEnvironment extends TestLogger {
         }
     }
 
+    // ------------------------------------------------------------------------------------------
+    // MySQL Variables (we always use MySQL as the data source for easier verifying)
+    // ------------------------------------------------------------------------------------------
+    protected static final String MYSQL_TEST_USER = "mysqluser";
+    protected static final String MYSQL_TEST_PASSWORD = "mysqlpw";
+    protected static final String INTER_CONTAINER_MYSQL_ALIAS = "mysql";
+    protected static final Duration EVENT_WAITING_TIMEOUT = Duration.ofMinutes(3);
+    protected static final Duration STARTUP_WAITING_TIMEOUT = Duration.ofMinutes(5);
+
+    public static final Network NETWORK = Network.newNetwork();
+
+    @Container
+    protected static final MySqlContainer MYSQL =
+            (MySqlContainer)
+                    new MySqlContainer(MySqlVersion.V8_0)
+                            .withConfigurationOverride("docker/mysql/my.cnf")
+                            .withSetupSQL("docker/mysql/setup.sql")
+                            .withDatabaseName("flink-test")
+                            .withUsername("flinkuser")
+                            .withPassword("flinkpw")
+                            .withNetwork(NETWORK)
+                            .withNetworkAliases("mysql")
+                            .withLogConsumer(new Slf4jLogConsumer(LOG));
+
     // ------------------------------------------------------------------------------------------
     // Flink Variables
     // ------------------------------------------------------------------------------------------
-    public static final int JOB_MANAGER_REST_PORT = 8081;
-    public static final String INTER_CONTAINER_JM_ALIAS = "jobmanager";
-    public static final String INTER_CONTAINER_TM_ALIAS = "taskmanager";
-    public static final List<String> EXTERNAL_PROPS =
+    protected static final int JOB_MANAGER_REST_PORT = 8081;
+    protected static final String INTER_CONTAINER_JM_ALIAS = "jobmanager";
+    protected static final String INTER_CONTAINER_TM_ALIAS = "taskmanager";
+    protected static final List<String> EXTERNAL_PROPS =
             Arrays.asList(
                     String.format("jobmanager.rpc.address: %s", INTER_CONTAINER_JM_ALIAS),
                     "jobmanager.bind-host: 0.0.0.0",
@@ -111,14 +137,12 @@ public abstract class PipelineTestEnvironment extends TestLogger {
                     "execution.checkpointing.interval: 300",
                     "state.backend.type: hashmap",
                     "env.java.opts.all: -Doracle.jdbc.timezoneAsRegion=false",
+                    "execution.checkpointing.savepoint-dir: file:///opt/flink",
                     "restart-strategy.type: off");
     public static final String FLINK_PROPERTIES = String.join("\n", EXTERNAL_PROPS);
 
-    @ClassRule public static final Network NETWORK = Network.newNetwork();
-
-    @Rule public final TemporaryFolder temporaryFolder = new TemporaryFolder();
-
     @Nullable protected RestClusterClient<StandaloneClusterId> restClusterClient;
+
     protected GenericContainer<?> jobManager;
     protected GenericContainer<?> taskManager;
     protected Volume sharedVolume = new Volume("/tmp/shared");
@@ -127,17 +151,18 @@ public abstract class PipelineTestEnvironment extends TestLogger {
 
     protected ToStringConsumer taskManagerConsumer;
 
-    @Parameterized.Parameters(name = "flinkVersion: {0}")
-    public static List<String> getFlinkVersion() {
+    protected String flinkVersion = getFlinkVersion();
+
+    public static String getFlinkVersion() {
         String flinkVersion = System.getProperty("specifiedFlinkVersion");
-        if (flinkVersion != null) {
-            return Collections.singletonList(flinkVersion);
-        } else {
-            return Arrays.asList("1.19.1", "1.20.0");
+        if (Objects.isNull(flinkVersion)) {
+            throw new IllegalArgumentException(
+                    "No Flink version specified to run this test. Please use -DspecifiedFlinkVersion to pass one.");
         }
+        return flinkVersion;
     }
 
-    @Before
+    @BeforeEach
     public void before() throws Exception {
         LOG.info("Starting containers...");
         jobManagerConsumer = new ToStringConsumer();
@@ -167,9 +192,12 @@ public abstract class PipelineTestEnvironment extends TestLogger {
         Startables.deepStart(Stream.of(taskManager)).join();
         runInContainerAsRoot(taskManager, "chmod", "0777", "-R", sharedVolume.toString());
         LOG.info("TaskManager is started.");
+
+        TarballFetcher.fetchLatest(jobManager);
+        LOG.info("CDC executables deployed.");
     }
 
-    @After
+    @AfterEach
     public void after() {
         if (restClusterClient != null) {
             restClusterClient.close();
@@ -182,51 +210,114 @@ public abstract class PipelineTestEnvironment extends TestLogger {
         }
     }
 
-    /** Allow overriding the default flink properties. */
-    public void overrideFlinkProperties(String properties) {
-        jobManager.withEnv("FLINK_PROPERTIES", properties);
-        taskManager.withEnv("FLINK_PROPERTIES", properties);
+    /**
+     * Submits a YAML job to the running cluster with latest CDC version, without from previous
+     * savepoint states.
+     */
+    public JobID submitPipelineJob(String pipelineJob, Path... jars) throws Exception {
+        return submitPipelineJob(
+                TarballFetcher.CdcVersion.SNAPSHOT, pipelineJob, null, false, jars);
     }
 
     /**
-     * Submits a SQL job to the running cluster.
-     *
-     * <p><b>NOTE:</b> You should not use {@code '\t'}.
+     * Submits a YAML job to the running cluster with specific CDC version, without from previous
+     * savepoint states.
      */
-    public void submitPipelineJob(String pipelineJob, Path... jars)
-            throws IOException, InterruptedException {
-        for (Path jar : jars) {
-            jobManager.copyFileToContainer(
-                    MountableFile.forHostPath(jar), "/tmp/flinkCDC/lib/" + jar.getFileName());
+    public JobID submitPipelineJob(
+            TarballFetcher.CdcVersion version, String pipelineJob, Path... jars) throws Exception {
+        return submitPipelineJob(version, pipelineJob, null, false, jars);
+    }
+
+    /** Submits a YAML job to the running cluster with latest CDC version. */
+    public JobID submitPipelineJob(
+            String pipelineJob,
+            @Nullable String savepointPath,
+            boolean allowNonRestoredState,
+            Path... jars)
+            throws Exception {
+        return submitPipelineJob(
+                TarballFetcher.CdcVersion.SNAPSHOT,
+                pipelineJob,
+                savepointPath,
+                allowNonRestoredState,
+                jars);
+    }
+
+    public JobID submitPipelineJob(
+            TarballFetcher.CdcVersion version,
+            String pipelineJob,
+            @Nullable String savepointPath,
+            boolean allowNonRestoredState,
+            Path... jars)
+            throws Exception {
+
+        // Prepare external JAR dependencies
+        List<Path> paths = new ArrayList<>(Arrays.asList(jars));
+        List<String> containerPaths = new ArrayList<>();
+        paths.add(TestUtils.getResource("mysql-driver.jar"));
+
+        for (Path jar : paths) {
+            String containerPath = version.workDir() + "/lib/" + jar.getFileName();
+            jobManager.copyFileToContainer(MountableFile.forHostPath(jar), containerPath);
+            containerPaths.add(containerPath);
         }
-        jobManager.copyFileToContainer(
-                MountableFile.forHostPath(
-                        TestUtils.getResource("flink-cdc.sh", "flink-cdc-dist", "src"), 755),
-                "/tmp/flinkCDC/bin/flink-cdc.sh");
-        jobManager.copyFileToContainer(
-                MountableFile.forHostPath(
-                        TestUtils.getResource("flink-cdc.yaml", "flink-cdc-dist", "src"), 755),
-                "/tmp/flinkCDC/conf/flink-cdc.yaml");
-        jobManager.copyFileToContainer(
-                MountableFile.forHostPath(TestUtils.getResource("flink-cdc-dist.jar")),
-                "/tmp/flinkCDC/lib/flink-cdc-dist.jar");
-        Path script = temporaryFolder.newFile().toPath();
-        Files.write(script, pipelineJob.getBytes());
-        jobManager.copyFileToContainer(
-                MountableFile.forHostPath(script), "/tmp/flinkCDC/conf/pipeline.yaml");
+
+        // Attach default MySQL and Values connectors
+        containerPaths.add(version.workDir() + "/lib/mysql-cdc-pipeline-connector.jar");
+        containerPaths.add(version.workDir() + "/lib/values-cdc-pipeline-connector.jar");
+
         StringBuilder sb = new StringBuilder();
-        for (Path jar : jars) {
-            sb.append(" --jar /tmp/flinkCDC/lib/").append(jar.getFileName());
+        for (String containerPath : containerPaths) {
+            sb.append(" --jar ").append(containerPath);
         }
+
+        jobManager.copyFileToContainer(
+                Transferable.of(pipelineJob), version.workDir() + "/conf/pipeline.yaml");
+
         String commands =
-                "/tmp/flinkCDC/bin/flink-cdc.sh /tmp/flinkCDC/conf/pipeline.yaml --flink-home /opt/flink"
+                version.workDir()
+                        + "/bin/flink-cdc.sh "
+                        + version.workDir()
+                        + "/conf/pipeline.yaml --flink-home /opt/flink"
                         + sb;
-        ExecResult execResult = jobManager.execInContainer("bash", "-c", commands);
-        LOG.info(execResult.getStdout());
-        LOG.error(execResult.getStderr());
-        if (execResult.getExitCode() != 0) {
-            throw new AssertionError("Failed when submitting the pipeline job.");
+
+        if (savepointPath != null) {
+            commands += " --from-savepoint " + savepointPath;
+            if (allowNonRestoredState) {
+                commands += " --allow-nonRestored-state";
+            }
         }
+        LOG.info("Execute command: {}", commands);
+        ExecResult execResult = executeAndCheck(jobManager, commands);
+        return Arrays.stream(execResult.getStdout().split("\n"))
+                .filter(line -> line.startsWith("Job ID: "))
+                .findFirst()
+                .map(line -> line.split(": ")[1])
+                .map(JobID::fromHexString)
+                .orElse(null);
+    }
+
+    public String stopJobWithSavepoint(JobID jobID) {
+        String savepointPath = "/opt/flink/";
+        ExecResult result =
+                executeAndCheck(
+                        jobManager,
+                        "flink",
+                        "stop",
+                        jobID.toHexString(),
+                        "--savepointPath",
+                        savepointPath);
+
+        return Arrays.stream(result.getStdout().split("\n"))
+                .filter(line -> line.startsWith("Savepoint completed."))
+                .findFirst()
+                .map(line -> line.split("Path: file:")[1])
+                .orElseThrow(
+                        () -> new RuntimeException("Failed to parse savepoint path from stdout."));
+    }
+
+    public void cancelJob(JobID jobID) {
+        executeAndCheck(jobManager, "flink", "cancel", jobID.toHexString());
     }
 
     /**
@@ -256,6 +347,14 @@ public abstract class PipelineTestEnvironment extends TestLogger {
     }
 
     public void waitUntilJobRunning(Duration timeout) {
+        waitUntilJobState(timeout, JobStatus.RUNNING);
+    }
+
+    public void waitUntilJobFinished(Duration timeout) {
+        waitUntilJobState(timeout, JobStatus.FINISHED);
+    }
+
+    public void waitUntilJobState(Duration timeout, JobStatus expectedStatus) {
         RestClusterClient<?> clusterClient = getRestClusterClient();
         Deadline deadline = Deadline.fromNow(timeout);
         while (deadline.hasTimeLeft()) {
@@ -269,14 +368,14 @@ public abstract class PipelineTestEnvironment extends TestLogger {
             if (jobStatusMessages != null && !jobStatusMessages.isEmpty()) {
                 JobStatusMessage message = jobStatusMessages.iterator().next();
                 JobStatus jobStatus = message.getJobState();
-                if (jobStatus.isTerminalState()) {
+                if (!expectedStatus.isTerminalState() && jobStatus.isTerminalState()) {
                     throw new ValidationException(
                             String.format(
                                     "Job has been terminated! JobName: %s, JobID: %s, Status: %s",
                                     message.getJobName(),
                                     message.getJobId(),
                                     message.getJobState()));
-                } else if (jobStatus == JobStatus.RUNNING) {
+                } else if (jobStatus == expectedStatus) {
                     return;
                 }
             }
@@ -287,29 +386,29 @@ public abstract class PipelineTestEnvironment extends TestLogger {
         return String.format("flink:%s-scala_2.12", flinkVersion);
     }
 
-    private static Version parseVersion(String version) {
-        List<Integer> versionParts =
-                Arrays.stream(version.split("\\."))
-                        .map(Integer::valueOf)
-                        .limit(3)
-                        .collect(Collectors.toList());
-        return new Version(
-                versionParts.get(0), versionParts.get(1), versionParts.get(2), null, null, null);
+    private ExecResult executeAndCheck(GenericContainer<?> container, String... command) {
+        String joinedCommand = String.join(" ", command);
+        try {
+            LOG.info("Executing command {}", joinedCommand);
+            ExecResult execResult =
+                    container.execInContainer("bash", "-c", String.join(" ", command));
+            LOG.info(execResult.getStdout());
+            if (execResult.getExitCode() == 0) {
+                LOG.info("Command executed successfully.");
+                return execResult;
+            } else {
+                LOG.error(execResult.getStderr());
+                throw new AssertionError(
+                        "Failed when submitting the pipeline job. Exit code: "
+                                + execResult.getExitCode());
+            }
+        } catch (Exception e) {
+            throw new RuntimeException(
+                    "Failed to execute command " + joinedCommand + " in container " + container);
+        }
     }
 
-    private static String getFlinkProperties() {
-        return String.join(
-                "\n",
-                Arrays.asList(
-                        "restart-strategy.type: off",
-                        "jobmanager.rpc.address: jobmanager",
-                        "taskmanager.numberOfTaskSlots: 10",
-                        "parallelism.default: 4",
-                        "execution.checkpointing.interval: 300",
-                        "env.java.opts.all: -Doracle.jdbc.timezoneAsRegion=false"));
-    }
-
-    private void runInContainerAsRoot(GenericContainer<?> container, String... command)
+    public void runInContainerAsRoot(GenericContainer<?> container, String... command)
             throws InterruptedException {
         ToStringConsumer stdoutConsumer = new ToStringConsumer();
         ToStringConsumer stderrConsumer = new ToStringConsumer();
@@ -332,4 +431,46 @@ public abstract class PipelineTestEnvironment extends TestLogger {
         Path path = new File(url.getFile()).toPath();
         return Files.readAllLines(path);
     }
+
+    protected void validateResult(String... expectedEvents) throws Exception {
+        validateResult(Function.identity(), expectedEvents);
+    }
+
+    protected void validateResult(Function<String, String> mapper, String... expectedEvents)
+            throws Exception {
+        validateResult(
+                taskManagerConsumer, Stream.of(expectedEvents).map(mapper).toArray(String[]::new));
+    }
+
+    protected void validateResult(ToStringConsumer consumer, String... expectedEvents)
+            throws Exception {
+        for (String event : expectedEvents) {
+            waitUntilSpecificEvent(consumer, event);
+        }
+    }
+
+    protected void waitUntilSpecificEvent(String event) throws Exception {
+        waitUntilSpecificEvent(taskManagerConsumer, event);
+    }
+
+    protected void waitUntilSpecificEvent(ToStringConsumer consumer, String event)
+            throws Exception {
+        boolean result = false;
+        long endTimeout = System.currentTimeMillis() + EVENT_WAITING_TIMEOUT.toMillis();
+        while (System.currentTimeMillis() < endTimeout) {
+            String stdout = consumer.toUtf8String();
+            if (stdout.contains(event + "\n")) {
+                result = true;
+                break;
+            }
+            Thread.sleep(1000);
+        }
+        if (!result) {
+            throw new TimeoutException(
+                    "failed to get specific event: "
+                            + event
+                            + " from stdout: "
+                            + consumer.toUtf8String());
+        }
+    }
 }
