@@ -20,14 +20,10 @@ package org.apache.flink.cdc.runtime.serializer.event;
 import org.apache.flink.api.common.typeutils.SimpleTypeSerializerSnapshot;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
 import org.apache.flink.api.common.typeutils.TypeSerializerSnapshot;
-import org.apache.flink.cdc.common.event.AddColumnEvent;
-import org.apache.flink.cdc.common.event.AlterColumnTypeEvent;
-import org.apache.flink.cdc.common.event.CreateTableEvent;
-import org.apache.flink.cdc.common.event.DropColumnEvent;
-import org.apache.flink.cdc.common.event.RenameColumnEvent;
 import org.apache.flink.cdc.common.event.SchemaChangeEvent;
 import org.apache.flink.cdc.common.event.SchemaChangeEventType;
 import org.apache.flink.cdc.common.event.TableId;
+import org.apache.flink.cdc.common.event.visitor.SchemaChangeEventVisitor;
 import org.apache.flink.cdc.runtime.serializer.EnumSerializer;
 import org.apache.flink.cdc.runtime.serializer.TypeSerializerSingleton;
 import org.apache.flink.core.memory.DataInputView;
@@ -35,6 +31,14 @@ import org.apache.flink.core.memory.DataOutputView;
 
 import java.io.IOException;
 
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.ADD_COLUMN;
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.ALTER_COLUMN_TYPE;
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.CREATE_TABLE;
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.DROP_COLUMN;
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.DROP_TABLE;
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.RENAME_COLUMN;
+import static org.apache.flink.cdc.common.event.SchemaChangeEventType.TRUNCATE_TABLE;
+
 /** A {@link TypeSerializer} for {@link SchemaChangeEvent}. */
 public final class SchemaChangeEventSerializer extends TypeSerializerSingleton<SchemaChangeEvent> {
 
@@ -54,13 +58,18 @@ public final class SchemaChangeEventSerializer extends TypeSerializerSingleton<S
     @Override
     public SchemaChangeEvent createInstance() {
         return new SchemaChangeEvent() {
+            @Override
+            public SchemaChangeEventType getType() {
+                return null;
+            }
+
             @Override
             public TableId tableId() {
                 return TableId.tableId("unknown", "unknown", "unknown");
             }
 
             @Override
-            public SchemaChangeEventType getType() {
+            public SchemaChangeEvent copy(TableId newTableId) {
                 return null;
             }
         };
@@ -68,19 +77,15 @@ public final class SchemaChangeEventSerializer extends TypeSerializerSingleton<S
 
     @Override
     public SchemaChangeEvent copy(SchemaChangeEvent from) {
-        if (from instanceof AlterColumnTypeEvent) {
-            return AlterColumnTypeEventSerializer.INSTANCE.copy((AlterColumnTypeEvent) from);
-        } else if (from instanceof CreateTableEvent) {
-            return CreateTableEventSerializer.INSTANCE.copy((CreateTableEvent) from);
-        } else if (from instanceof RenameColumnEvent) {
-            return RenameColumnEventSerializer.INSTANCE.copy((RenameColumnEvent) from);
-        } else if (from instanceof AddColumnEvent) {
-            return AddColumnEventSerializer.INSTANCE.copy((AddColumnEvent) from);
-        } else if (from instanceof DropColumnEvent) {
-            return DropColumnEventSerializer.INSTANCE.copy((DropColumnEvent) from);
-        } else {
-            throw new IllegalArgumentException("Unknown schema change event: " + from);
-        }
+        return SchemaChangeEventVisitor.visit(
+                from,
+                AddColumnEventSerializer.INSTANCE::copy,
+                AlterColumnTypeEventSerializer.INSTANCE::copy,
+                CreateTableEventSerializer.INSTANCE::copy,
+                DropColumnEventSerializer.INSTANCE::copy,
+                DropTableEventSerializer.INSTANCE::copy,
+                RenameColumnEventSerializer.INSTANCE::copy,
+                TruncateTableEventSerializer.INSTANCE::copy);
     }
 
     @Override
@@ -95,25 +100,44 @@ public final class SchemaChangeEventSerializer extends TypeSerializerSingleton<S
 
     @Override
     public void serialize(SchemaChangeEvent record, DataOutputView target) throws IOException {
-        if (record instanceof AlterColumnTypeEvent) {
-            enumSerializer.serialize(SchemaChangeEventType.ALTER_COLUMN_TYPE, target);
-            AlterColumnTypeEventSerializer.INSTANCE.serialize(
-                    (AlterColumnTypeEvent) record, target);
-        } else if (record instanceof CreateTableEvent) {
-            enumSerializer.serialize(SchemaChangeEventType.CREATE_TABLE, target);
-            CreateTableEventSerializer.INSTANCE.serialize((CreateTableEvent) record, target);
-        } else if (record instanceof RenameColumnEvent) {
-            enumSerializer.serialize(SchemaChangeEventType.RENAME_COLUMN, target);
-            RenameColumnEventSerializer.INSTANCE.serialize((RenameColumnEvent) record, target);
-        } else if (record instanceof AddColumnEvent) {
-            enumSerializer.serialize(SchemaChangeEventType.ADD_COLUMN, target);
-            AddColumnEventSerializer.INSTANCE.serialize((AddColumnEvent) record, target);
-        } else if (record instanceof DropColumnEvent) {
-            enumSerializer.serialize(SchemaChangeEventType.DROP_COLUMN, target);
-            DropColumnEventSerializer.INSTANCE.serialize((DropColumnEvent) record, target);
-        } else {
-            throw new IllegalArgumentException("Unknown schema change event: " + record);
-        }
+
+        SchemaChangeEventVisitor.<Void, IOException>visit(
+                record,
+                addColumnEvent -> {
+                    enumSerializer.serialize(ADD_COLUMN, target);
+                    AddColumnEventSerializer.INSTANCE.serialize(addColumnEvent, target);
+                    return null;
+                },
+                alterColumnTypeEvent -> {
+                    enumSerializer.serialize(ALTER_COLUMN_TYPE, target);
+                    AlterColumnTypeEventSerializer.INSTANCE.serialize(alterColumnTypeEvent, target);
+                    return null;
+                },
+                createTableEvent -> {
+                    enumSerializer.serialize(CREATE_TABLE, target);
+                    CreateTableEventSerializer.INSTANCE.serialize(createTableEvent, target);
+                    return null;
+                },
+                dropColumnEvent -> {
+                    enumSerializer.serialize(DROP_COLUMN, target);
+                    DropColumnEventSerializer.INSTANCE.serialize(dropColumnEvent, target);
+                    return null;
+                },
+                dropTableEvent -> {
+                    enumSerializer.serialize(DROP_TABLE, target);
+                    DropTableEventSerializer.INSTANCE.serialize(dropTableEvent, target);
+                    return null;
+                },
+                renameColumnEvent -> {
+                    enumSerializer.serialize(RENAME_COLUMN, target);
+                    RenameColumnEventSerializer.INSTANCE.serialize(renameColumnEvent, target);
+                    return null;
+                },
+                truncateTableEvent -> {
+                    enumSerializer.serialize(TRUNCATE_TABLE, target);
+                    TruncateTableEventSerializer.INSTANCE.serialize(truncateTableEvent, target);
+                    return null;
+                });
     }
 
     @Override
@@ -130,6 +154,10 @@ public final class SchemaChangeEventSerializer extends TypeSerializerSingleton<S
                 return RenameColumnEventSerializer.INSTANCE.deserialize(source);
             case ALTER_COLUMN_TYPE:
                 return AlterColumnTypeEventSerializer.INSTANCE.deserialize(source);
+            case DROP_TABLE:
+                return DropTableEventSerializer.INSTANCE.deserialize(source);
+            case TRUNCATE_TABLE:
+                return TruncateTableEventSerializer.INSTANCE.deserialize(source);
             default:
                 throw new IllegalArgumentException(
                         "Unknown schema change event class: " + schemaChangeEventType);
